"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6.QtCore import *
import enum


class QTextStream(QIODeviceBase):
    """
    https://doc.qt.io/qt-6/qtextstream.html

    **Detailed Description**

    QTextStream can operate on a **QIODevice** , a **QByteArray**  or a
    **QString** . Using QTextStream's streaming operators, you can conveniently
    read and write words, lines and numbers. For generating text, QTextStream
    supports formatting options for field padding and alignment, and formatting
    of numbers. Example:

    **QFile**  data("output.txt");
        if (data.open(**QFile** ::WriteOnly |
    **QFile** ::Truncate)) {
            **QTextStream**  out(&data);
            out <<
    "Result: " << **qSetFieldWidth** (10) << left << 3.14 << 2.7;
            //
    writes "Result: 3.14      2.7       "
        }

    It's also common to use QTextStream to read console input and write console
    output. QTextStream is locale aware, and will automatically decode standard
    input using the correct encoding. Example:

    **QTextStream**  stream(stdin);
        **QString**  line;
        while
    (stream.readLineInto(&line)) {
            ...
        }

    Besides using QTextStream's constructors, you can also set the device or
    string QTextStream operates on by calling **setDevice** () or **setString**
    (). You can seek to a position by calling **seek** (), and **atEnd** () will
    return true when there is no data left to be read. If you call **flush** (),
    QTextStream will empty all data from its write buffer into the device and
    call **flush** () on the device.

    Internally, QTextStream uses a Unicode based buffer, and
    **QStringConverter**  is used by QTextStream to automatically support
    different encodings. By default, UTF-8 is used for reading and writing, but
    you can also set the encoding by calling **setEncoding** (). Automatic
    Unicode detection is also supported. When this feature is enabled (the
    default behavior), QTextStream will detect the UTF-8, UTF-16 or the UTF-32
    BOM (Byte Order Mark) and switch to the appropriate UTF encoding when
    reading. QTextStream does not write a BOM by default, but you can enable
    this by calling **setGenerateByteOrderMark** (true). When QTextStream
    operates on a **QString**  directly, the encoding is disabled.

    There are three general ways to use QTextStream when reading text files:

    * Chunk by chunk, by calling **readLine** () or **readAll** ().
      * Word by
    word. QTextStream supports streaming into **QString** s, **QByteArray** s
    and char* buffers. Words are delimited by space, and leading white space is
    automatically skipped.
      * Character by character, by streaming into
    **QChar**  or char types. This method is often used for convenient input
    handling when parsing files, independent of character encoding and end-of-
    line semantics. To skip white space, call **skipWhiteSpace** ().

    Since the text stream uses a buffer, you should not read from the stream
    using the implementation of a superclass. For instance, if you have a
    **QFile**  and read from it directly using **QFile::readLine** () instead of
    using the stream, the text stream's internal position will be out of sync
    with the file's position.

    By default, when reading numbers from a stream of text, QTextStream will
    automatically detect the number's base representation. For example, if the
    number starts with "0x", it is assumed to be in hexadecimal form. If it
    starts with the digits 1-9, it is assumed to be in decimal form, and so on.
    You can set the integer base, thereby disabling the automatic detection, by
    calling **setIntegerBase** (). Example:

    **QTextStream**  in("0x50 0x20");
        int firstNumber, secondNumber;
    in >> firstNumber;             // firstNumber == 80
        in >> dec >>
    secondNumber;     // secondNumber == 0

        char ch;
        in >> ch;
    // ch == 'x'

    QTextStream supports many formatting options for generating text. You can
    set the field width and pad character by calling **setFieldWidth** () and
    **setPadChar** (). Use **setFieldAlignment** () to set the alignment within
    each field. For real numbers, call **setRealNumberNotation** () and
    **setRealNumberPrecision** () to set the notation (**SmartNotation** ,
    **ScientificNotation** , **FixedNotation** ) and precision in digits of the
    generated number. Some extra number formatting options are also available
    through **setNumberFlags** ().

    Like `<iostream>` in the standard C++ library, QTextStream also defines
    several global manipulator functions:

    ManipulatorDescription
    **Qt::bin** Same as **setIntegerBase** (2).
    **Qt::oct** Same as **setIntegerBase** (8).
    **Qt::dec** Same as
    **setIntegerBase** (10).
    **Qt::hex** Same as **setIntegerBase** (16).
    **Qt::showbase** Same as **setNumberFlags** (**numberFlags** () |
    **ShowBase** ).
    **Qt::forcesign** Same as **setNumberFlags**
    (**numberFlags** () | **ForceSign** ).
    **Qt::forcepoint** Same as
    **setNumberFlags** (**numberFlags** () | **ForcePoint** ).
    **Qt::noshowbase** Same as **setNumberFlags** (**numberFlags** () &
    ~**ShowBase** ).
    **Qt::noforcesign** Same as **setNumberFlags**
    (**numberFlags** () & ~**ForceSign** ).
    **Qt::noforcepoint** Same as
    **setNumberFlags** (**numberFlags** () & ~**ForcePoint** ).
    **Qt::uppercasebase** Same as **setNumberFlags** (**numberFlags** () |
    **UppercaseBase** ).
    **Qt::uppercasedigits** Same as **setNumberFlags**
    (**numberFlags** () | **UppercaseDigits** ).
    **Qt::lowercasebase** Same as
    **setNumberFlags** (**numberFlags** () & ~**UppercaseBase** ).
    **Qt::lowercasedigits** Same as **setNumberFlags** (**numberFlags** () &
    ~**UppercaseDigits** ).
    **Qt::fixed** Same as **setRealNumberNotation**
    (**FixedNotation** ).
    **Qt::scientific** Same as **setRealNumberNotation**
    (**ScientificNotation** ).
    **Qt::left** Same as **setFieldAlignment**
    (**AlignLeft** ).
    **Qt::right** Same as **setFieldAlignment**
    (**AlignRight** ).
    **Qt::center** Same as **setFieldAlignment**
    (**AlignCenter** ).
    **Qt::endl** Same as operator<<('\\n') and **flush**
    ().
    **Qt::flush** Same as **flush** ().
    **Qt::reset** Same as **reset**
    ().
    **Qt::ws** Same as **skipWhiteSpace** ().
    **Qt::bom** Same as
    **setGenerateByteOrderMark** (true).

    In addition, Qt provides three global manipulators that take a parameter:
    **qSetFieldWidth** (), **qSetPadChar** (), and **qSetRealNumberPrecision**
    ().

    **See also** **QDataStream** , **QIODevice** , **QFile** , **QBuffer** , and
    **QTcpSocket** .
    """

    class NumberFlag(enum.Flag):
        ShowBase: QTextStream = ...
        ForcePoint: QTextStream = ...
        ForceSign: QTextStream = ...
        UppercaseBase: QTextStream = ...
        UppercaseDigits: QTextStream = ...

    class Status(enum.Enum):
        Ok: QTextStream = ...
        ReadPastEnd: QTextStream = ...
        ReadCorruptData: QTextStream = ...
        WriteFailed: QTextStream = ...

    class FieldAlignment(enum.Enum):
        AlignLeft: QTextStream = ...
        AlignRight: QTextStream = ...
        AlignCenter: QTextStream = ...
        AlignAccountingStyle: QTextStream = ...

    class RealNumberNotation(enum.Enum):
        SmartNotation: QTextStream = ...
        FixedNotation: QTextStream = ...
        ScientificNotation: QTextStream = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextstream.html#QTextStream

        **QTextStream::QTextStream()**

        Constructs a QTextStream. Before you can use it for reading or writing,
        you must assign a device or a string.

        **See also** **setDevice** () and **setString** ().
        """
        ...

    @typing.overload
    def __init__(self, device: QIODevice) -> None:
        """
        https://doc.qt.io/qt-6/qtextstream.html#QTextStream-1

        **QTextStream::QTextStream(QIODevice * device )**

        Constructs a QTextStream that operates on **device**.
        """
        ...

    @typing.overload
    def __init__(
        self, array: QByteArray, mode: QIODeviceBase.OpenModeFlag = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtextstream.html#QTextStream-2

        **QTextStream::QTextStream(FILE * fileHandle , QIODeviceBase::OpenMode
        openMode = ReadWrite)**

        Constructs a QTextStream that operates on **fileHandle** , using
        **openMode** to define the open mode. Internally, a **QFile**  is
        created to handle the FILE pointer.

        This constructor is useful for working directly with the common FILE
        based input and output streams: stdin, stdout and stderr. Example:

        **QString**  str;
            **QTextStream**  in(stdin);
            in >> str;
        """
        ...

    def realNumberPrecision(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextstream.html#realNumberPrecision

        **int QTextStream::realNumberPrecision() const**

        Returns the current real number precision, or the number of fraction
        digits **QTextStream**  will write when generating real numbers.

        **See also** **setRealNumberPrecision** (), **setRealNumberNotation**
        (), **realNumberNotation** (), **numberFlags** (), and **integerBase**
        ().
        """
        ...

    def setRealNumberPrecision(self, precision: int) -> None:
        """
        https://doc.qt.io/qt-6/qtextstream.html#setRealNumberPrecision

        **void QTextStream::setRealNumberPrecision(int precision )**

        Sets the precision of real numbers to **precision**. This value
        describes the number of fraction digits **QTextStream**  should write
        when generating real numbers.

        The precision cannot be a negative value. The default value is 6.

        **See also** **realNumberPrecision** () and **setRealNumberNotation**
        ().
        """
        ...

    def realNumberNotation(self) -> "QTextStream.RealNumberNotation":
        """
        https://doc.qt.io/qt-6/qtextstream.html#realNumberNotation

        **QTextStream::RealNumberNotation QTextStream::realNumberNotation()
        const**

        Returns the current real number notation.

        **See also** **setRealNumberNotation** (), **realNumberPrecision** (),
        **numberFlags** (), and **integerBase** ().
        """
        ...

    def setRealNumberNotation(self, notation: "QTextStream.RealNumberNotation") -> None:
        """
        https://doc.qt.io/qt-6/qtextstream.html#setRealNumberNotation

        **void
        QTextStream::setRealNumberNotation(QTextStream::RealNumberNotation
        notation )**

        Sets the real number notation to **notation** (**SmartNotation** ,
        **FixedNotation** , **ScientificNotation** ). When reading and
        generating numbers, **QTextStream**  uses this value to detect the
        formatting of real numbers.

        **See also** **realNumberNotation** (), **setRealNumberPrecision** (),
        **setNumberFlags** (), and **setIntegerBase** ().
        """
        ...

    def integerBase(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextstream.html#integerBase

        **int QTextStream::integerBase() const**

        Returns the current base of integers. 0 means that the base is detected
        when reading, or 10 (decimal) when generating numbers.

        **See also** **setIntegerBase** (), **QString::number** (), and
        **numberFlags** ().
        """
        ...

    def setIntegerBase(self, base: int) -> None:
        """
        https://doc.qt.io/qt-6/qtextstream.html#setIntegerBase

        **void QTextStream::setIntegerBase(int base )**

        Sets the base of integers to **base** , both for reading and for
        generating numbers. **base** can be either 2 (binary), 8 (octal), 10
        (decimal) or 16 (hexadecimal). If **base** is 0, **QTextStream**  will
        attempt to detect the base by inspecting the data on the stream. When
        generating numbers, **QTextStream**  assumes base is 10 unless the base
        has been set explicitly.

        **See also** **integerBase** (), **QString::number** (), and
        **setNumberFlags** ().
        """
        ...

    def numberFlags(self) -> "QTextStream.NumberFlag":
        """
        https://doc.qt.io/qt-6/qtextstream.html#numberFlags

        **QTextStream::NumberFlags QTextStream::numberFlags() const**

        Returns the current number flags.

        **See also** **setNumberFlags** (), **integerBase** (), and
        **realNumberNotation** ().
        """
        ...

    def setNumberFlags(self, flags: "QTextStream.NumberFlag") -> None:
        """
        https://doc.qt.io/qt-6/qtextstream.html#setNumberFlags

        **void QTextStream::setNumberFlags(QTextStream::NumberFlags flags )**

        Sets the current number flags to **flags**. **flags** is a set of flags
        from the **NumberFlag**  enum, and describes options for formatting
        generated code (e.g., whether or not to always write the base or sign of
        a number).

        **See also** **numberFlags** (), **setIntegerBase** (), and
        **setRealNumberNotation** ().
        """
        ...

    def fieldWidth(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextstream.html#fieldWidth

        **int QTextStream::fieldWidth() const**

        Returns the current field width.

        **See also** **setFieldWidth** ().
        """
        ...

    def setFieldWidth(self, width: int) -> None:
        """
        https://doc.qt.io/qt-6/qtextstream.html#setFieldWidth

        **void QTextStream::setFieldWidth(int width )**

        Sets the current field width to **width**. If **width** is 0 (the
        default), the field width is equal to the length of the generated text.

        **Note:** The field width applies to every element appended to this
        stream after this function has been called (e.g., it also pads endl).
        This behavior is different from similar classes in the STL, where the
        field width only applies to the next element.

        **See also** **fieldWidth** () and **setPadChar** ().
        """
        ...

    def padChar(self) -> str:
        """
        https://doc.qt.io/qt-6/qtextstream.html#padChar

        **QChar QTextStream::padChar() const**

        Returns the current pad character.

        **See also** **setPadChar** () and **setFieldWidth** ().
        """
        ...

    def setPadChar(self, ch: str) -> None:
        """
        https://doc.qt.io/qt-6/qtextstream.html#setPadChar

        **void QTextStream::setPadChar(QChar ch )**

        Sets the pad character to **ch**. The default value is the ASCII space
        character (' '), or **QChar** (0x20). This character is used to fill in
        the space in fields when generating text.

        Example:

        **QString**  s;
            **QTextStream**  out(&s);
            out.setFieldWidth(10);
        out.setFieldAlignment(**QTextStream** ::AlignCenter);
        out.setPadChar('-');
            out << "Qt" << "rocks!";

        The string `s` contains:

        ----Qt------rocks!--

        **See also** **padChar** () and **setFieldWidth** ().
        """
        ...

    def fieldAlignment(self) -> "QTextStream.FieldAlignment":
        """
        https://doc.qt.io/qt-6/qtextstream.html#fieldAlignment

        **QTextStream::FieldAlignment QTextStream::fieldAlignment() const**

        Returns the current field alignment.

        **See also** **setFieldAlignment** () and **fieldWidth** ().
        """
        ...

    def setFieldAlignment(self, alignment: "QTextStream.FieldAlignment") -> None:
        """
        https://doc.qt.io/qt-6/qtextstream.html#setFieldAlignment

        **void QTextStream::setFieldAlignment(QTextStream::FieldAlignment mode
        )**

        Sets the field alignment to **mode**. When used together with
        **setFieldWidth** (), this function allows you to generate formatted
        output with text aligned to the left, to the right or center aligned.

        **See also** **fieldAlignment** () and **setFieldWidth** ().
        """
        ...

    def read(self, maxlen: int) -> str:
        """
        https://doc.qt.io/qt-6/qtextstream.html#read

        **QString QTextStream::read(qint64 maxlen )**

        Reads at most **maxlen** characters from the stream, and returns the
        data read as a **QString** .

        **See also** **readAll** (), **readLine** (), and **QIODevice::read**
        ().
        """
        ...

    def readAll(self) -> str:
        """
        https://doc.qt.io/qt-6/qtextstream.html#readAll

        **QString QTextStream::readAll()**

        Reads the entire content of the stream, and returns it as a **QString**
        . Avoid this function when working on large files, as it will consume a
        significant amount of memory.

        Calling **readLine** () is better if you do not know how much data is
        available.

        **See also** **readLine** ().
        """
        ...

    def readLine(self, maxLength: int = ...) -> str:
        """
        https://doc.qt.io/qt-6/qtextstream.html#readLine

        **QString QTextStream::readLine(qint64 maxlen = 0)**

        Reads one line of text from the stream, and returns it as a **QString**
        . The maximum allowed line length is set to **maxlen**. If the stream
        contains lines longer than this, then the lines will be split after
        **maxlen** characters and returned in parts.

        If **maxlen** is 0, the lines can be of any length.

        The returned line has no trailing end-of-line characters ("\\n" or
        "\\r\\n"), so calling **QString::trimmed** () can be unnecessary.

        If the stream has read to the end of the file, readLine() will return a
        null **QString** . For strings, or for devices that support it, you can
        explicitly test for the end of the stream using **atEnd** ().

        **See also** **readAll** () and **QIODevice::readLine** ().
        """
        ...

    def skipWhiteSpace(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextstream.html#skipWhiteSpace

        **void QTextStream::skipWhiteSpace()**

        Reads and discards whitespace from the stream until either a non-space
        character is detected, or until **atEnd** () returns true. This function
        is useful when reading a stream character by character.

        Whitespace characters are all characters for which **QChar::isSpace** ()
        returns `true`.

        **See also** **operator>>** ().
        """
        ...

    def pos(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextstream.html#pos

        **qint64 QTextStream::pos() const**

        Returns the device position corresponding to the current position of the
        stream, or -1 if an error occurs (e.g., if there is no device or string,
        or if there's a device error).

        Because **QTextStream**  is buffered, this function may have to seek the
        device to reconstruct a valid device position. This operation can be
        expensive, so you may want to avoid calling this function in a tight
        loop.

        **See also** **seek** ().
        """
        ...

    def seek(self, pos: int) -> bool:
        """
        https://doc.qt.io/qt-6/qtextstream.html#seek

        **bool QTextStream::seek(qint64 pos )**

        Seeks to the position **pos** in the device. Returns `true` on success;
        otherwise returns `false`.
        """
        ...

    def flush(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextstream.html#flush

        **void QTextStream::flush()**

        Flushes any buffered data waiting to be written to the device.

        If **QTextStream**  operates on a string, this function does nothing.
        """
        ...

    def reset(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextstream.html#reset

        **void QTextStream::reset()**

        Resets **QTextStream** 's formatting options, bringing it back to its
        original constructed state. The device, string and any buffered data is
        left untouched.
        """
        ...

    def atEnd(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextstream.html#atEnd

        **bool QTextStream::atEnd() const**

        Returns `true` if there is no more data to be read from the
        **QTextStream** ; otherwise returns `false`. This is similar to, but not
        the same as calling **QIODevice::atEnd** (), as **QTextStream**  also
        takes into account its internal Unicode buffer.
        """
        ...

    def resetStatus(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextstream.html#resetStatus

        **void QTextStream::resetStatus()**

        Resets the status of the text stream.

        **See also** **QTextStream::Status** , **status** (), and **setStatus**
        ().
        """
        ...

    def setStatus(self, status: "QTextStream.Status") -> None:
        """
        https://doc.qt.io/qt-6/qtextstream.html#setStatus

        **void QTextStream::setStatus(QTextStream::Status status )**

        Sets the status of the text stream to the **status** given.

        Subsequent calls to setStatus() are ignored until **resetStatus** () is
        called.

        **See also** **Status** , **status** (), and **resetStatus** ().
        """
        ...

    def status(self) -> "QTextStream.Status":
        """
        https://doc.qt.io/qt-6/qtextstream.html#status

        **QTextStream::Status QTextStream::status() const**

        Returns the status of the text stream.

        **See also** **QTextStream::Status** , **setStatus** (), and
        **resetStatus** ().
        """
        ...

    def device(self) -> QIODevice:
        """
        https://doc.qt.io/qt-6/qtextstream.html#device

        **QIODevice *QTextStream::device() const**

        Returns the current device associated with the **QTextStream** , or
        `nullptr` if no device has been assigned.

        **See also** **setDevice** () and **string** ().
        """
        ...

    def setDevice(self, device: QIODevice) -> None:
        """
        https://doc.qt.io/qt-6/qtextstream.html#setDevice

        **void QTextStream::setDevice(QIODevice * device )**

        Sets the current device to **device**. If a device has already been
        assigned, **QTextStream**  will call **flush** () before the old device
        is replaced.

        **Note:** This function resets locale to the default locale ('C') and
        encoding to the default encoding, UTF-8.

        **See also** **device** () and **setString** ().
        """
        ...

    def locale(self) -> QLocale:
        """
        https://doc.qt.io/qt-6/qtextstream.html#locale

        **QLocale QTextStream::locale() const**

        Returns the locale for this stream. The default locale is C.

        **See also** **setLocale** ().
        """
        ...

    def setLocale(self, locale: QLocale) -> None:
        """
        https://doc.qt.io/qt-6/qtextstream.html#setLocale

        **void QTextStream::setLocale(const QLocale & locale )**

        Sets the locale for this stream to **locale**. The specified locale is
        used for conversions between numbers and their string representations.

        The default locale is C and it is a special case - the thousands group
        separator is not used for backward compatibility reasons.

        **See also** **locale** ().
        """
        ...

    def generateByteOrderMark(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextstream.html#generateByteOrderMark

        **bool QTextStream::generateByteOrderMark() const**

        Returns `true` if **QTextStream**  is set to generate the UTF BOM (Byte
        Order Mark) when using a UTF encoding; otherwise returns `false`. UTF
        BOM generation is set to false by default.

        **See also** **setGenerateByteOrderMark** ().
        """
        ...

    def setGenerateByteOrderMark(self, generate: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtextstream.html#setGenerateByteOrderMark

        **void QTextStream::setGenerateByteOrderMark(bool generate )**

        If **generate** is true and a UTF encoding is used, **QTextStream**
        will insert the BOM (Byte Order Mark) before any data has been written
        to the device. If **generate** is false, no BOM will be inserted. This
        function must be called before any data is written. Otherwise, it does
        nothing.

        **See also** **generateByteOrderMark** () and **bom** ().
        """
        ...

    def autoDetectUnicode(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextstream.html#autoDetectUnicode

        **bool QTextStream::autoDetectUnicode() const**

        Returns `true` if automatic Unicode detection is enabled, otherwise
        returns `false`. Automatic Unicode detection is enabled by default.

        **See also** **setAutoDetectUnicode** () and **setEncoding** ().
        """
        ...

    def setAutoDetectUnicode(self, enabled: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtextstream.html#setAutoDetectUnicode

        **void QTextStream::setAutoDetectUnicode(bool enabled )**

        If **enabled** is true, **QTextStream**  will attempt to detect Unicode
        encoding by peeking into the stream data to see if it can find the
        UTF-8, UTF-16, or UTF-32 Byte Order Mark (BOM). If this mark is found,
        **QTextStream**  will replace the current encoding with the UTF
        encoding.

        This function can be used together with **setEncoding** (). It is common
        to set the encoding to UTF-8, and then enable UTF-16 detection.

        **See also** **autoDetectUnicode** () and **setEncoding** ().
        """
        ...

    def encoding(self) -> QStringConverter.Encoding:
        """
        https://doc.qt.io/qt-6/qtextstream.html#encoding

        **QStringConverter::Encoding QTextStream::encoding() const**

        Returns the encoding that is current assigned to the stream.

        **See also** **setEncoding** (), **setAutoDetectUnicode** (), and
        **locale** ().
        """
        ...

    def setEncoding(self, encoding: QStringConverter.Encoding) -> None:
        """
        https://doc.qt.io/qt-6/qtextstream.html#setEncoding

        **void QTextStream::setEncoding(QStringConverter::Encoding encoding )**

        Sets the encoding for this stream to **encoding**. The encoding is used
        for decoding any data that is read from the assigned device, and for
        encoding any data that is written. By default,
        **QStringConverter::Utf8**  is used, and automatic unicode detection is
        enabled.

        If **QTextStream**  operates on a string, this function does nothing.

        **Warning:** If you call this function while the text stream is reading
        from an open sequential socket, the internal buffer may still contain
        text decoded using the old encoding.

        **See also** **encoding** (), **setAutoDetectUnicode** (), and
        **setLocale** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtGui import *


class QFontInfo(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qfontinfo.html

    **Detailed Description**

    The QFontInfo class provides the same access functions as **QFont** , e.g.
    **family** (), **pointSize** (), **italic** (), **weight** (),
    **fixedPitch** (), **styleHint** () etc. But whilst the **QFont**  access
    functions return the values that were set, a QFontInfo object returns the
    values that apply to the font that will actually be used to draw the text.

    For example, when the program asks for a 25pt Courier font on a machine that
    has a non-scalable 24pt Courier font, **QFont**  will (normally) use the
    24pt Courier for rendering. In this case, **QFont::pointSize** () returns 25
    and **QFontInfo::pointSize** () returns 24.

    There are three ways to create a QFontInfo object.

    1. Calling the QFontInfo constructor with a **QFont**  creates a font info
    object for a screen-compatible font, i.e. the font cannot be a printer font.
    If the font is changed later, the font info object is **not** updated.
    (Note: If you use a printer font the values returned may be inaccurate.
    Printer fonts are not always accessible so the nearest screen font is used
    if a printer font is supplied.)

      2. **QWidget::fontInfo** () returns the
    font info for a widget's font. This is equivalent to calling
    QFontInfo(widget->font()). If the widget's font is changed later, the font
    info object is **not** updated.
      3. **QPainter::fontInfo** () returns the
    font info for a painter's current font. If the painter's font is changed
    later, the font info object is **not** updated.

    **See also** **QFont** , **QFontMetrics** , and **QFontDatabase** .
    """

    @typing.overload
    def __init__(self, a0: QFont) -> None:
        """
        https://doc.qt.io/qt-6/qfontinfo.html#QFontInfo

        **QFontInfo::QFontInfo(const QFont & font )**

        Constructs a font info object for **font**.

        The font must be screen-compatible, i.e. a font you use when drawing
        text in **widgets**  or **pixmaps** , not **QPicture**  or **QPrinter**
        .

        The font info object holds the information for the font that is passed
        in the constructor at the time it is created, and is not updated if the
        font's attributes are changed later.

        Use **QPainter::fontInfo** () to get the font info when painting. This
        will give correct results also when painting on paint device that is not
        screen-compatible.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QFontInfo") -> None:
        """
        https://doc.qt.io/qt-6/qfontinfo.html#QFontInfo-1

        **QFontInfo::QFontInfo(const QFontInfo & fi )**

        Constructs a copy of **fi**.
        """
        ...

    def swap(self, other: "QFontInfo") -> None:
        """
        https://doc.qt.io/qt-6/qfontinfo.html#swap

        **[since 5.0] void QFontInfo::swap(QFontInfo & other )**

        Swaps this font info instance with **other**. This function is very fast
        and never fails.

        This function was introduced in Qt 5.0.
        """
        ...

    def styleName(self) -> str:
        """
        https://doc.qt.io/qt-6/qfontinfo.html#styleName

        **QString QFontInfo::styleName() const**

        Returns the style name of the matched window system font on systems that
        support it.

        **See also** **QFont::styleName** ().
        """
        ...

    def exactMatch(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfontinfo.html#exactMatch

        **bool QFontInfo::exactMatch() const**

        Returns `true` if the matched window system font is exactly the same as
        the one specified by the font; otherwise returns `false`.

        **See also** **QFont::exactMatch** ().
        """
        ...

    def styleHint(self) -> QFont.StyleHint:
        """
        https://doc.qt.io/qt-6/qfontinfo.html#styleHint

        **QFont::StyleHint QFontInfo::styleHint() const**

        Returns the style of the matched window system font.

        Currently only returns the style hint set in **QFont** .

        **See also** **QFont::styleHint** () and **QFont::StyleHint** .
        """
        ...

    def fixedPitch(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfontinfo.html#fixedPitch

        **bool QFontInfo::fixedPitch() const**

        Returns the fixed pitch value of the matched window system font.

        **See also** **QFont::fixedPitch** ().
        """
        ...

    def bold(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfontinfo.html#bold

        **bool QFontInfo::bold() const**

        Returns `true` if **weight** () would return a value greater than
        **QFont::Normal** ; otherwise returns `false`.

        **See also** **weight** () and **QFont::bold** ().
        """
        ...

    def weight(self) -> int:
        """
        https://doc.qt.io/qt-6/qfontinfo.html#weight

        **int QFontInfo::weight() const**

        Returns the weight of the matched window system font.

        **See also** **QFont::weight** () and **bold** ().
        """
        ...

    def style(self) -> QFont.Style:
        """
        https://doc.qt.io/qt-6/qfontinfo.html#style

        **QFont::Style QFontInfo::style() const**

        Returns the style value of the matched window system font.

        **See also** **QFont::style** ().
        """
        ...

    def italic(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfontinfo.html#italic

        **bool QFontInfo::italic() const**

        Returns the italic value of the matched window system font.

        **See also** **QFont::italic** ().
        """
        ...

    def pointSizeF(self) -> float:
        """
        https://doc.qt.io/qt-6/qfontinfo.html#pointSizeF

        **qreal QFontInfo::pointSizeF() const**

        Returns the point size of the matched window system font.

        **See also** **QFont::pointSizeF** ().
        """
        ...

    def pointSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qfontinfo.html#pointSize

        **int QFontInfo::pointSize() const**

        Returns the point size of the matched window system font.

        **See also** **pointSizeF** () and **QFont::pointSize** ().
        """
        ...

    def pixelSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qfontinfo.html#pixelSize

        **int QFontInfo::pixelSize() const**

        Returns the pixel size of the matched window system font.

        **See also** **QFont::pointSize** ().
        """
        ...

    def family(self) -> str:
        """
        https://doc.qt.io/qt-6/qfontinfo.html#family

        **QString QFontInfo::family() const**

        Returns the family name of the matched window system font.

        **See also** **QFont::family** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QNativeGestureEvent(QSinglePointEvent):
    """
    https://doc.qt.io/qt-6/qnativegestureevent.html

    **Detailed Description**

    Native gesture events are generated by the operating system, typically by
    interpreting trackpad touch events. Gesture events are high-level events
    such as zoom, rotate or pan. Several types hold incremental values: that is,
    **value** () and **delta** () provide the difference from the previous event
    to the current event.

    Event TypeDescriptionTouch sequence
    **Qt::ZoomNativeGesture**
    Magnification delta in percent.macOS and Wayland: Two-finger pinch.
    **Qt::SmartZoomNativeGesture** Boolean magnification state.macOS: Two-finger
    douple tap (trackpad) / One-finger douple tap (magic mouse).
    **Qt::RotateNativeGesture** Rotation delta in degrees.macOS and Wayland:
    Two-finger rotate.
    **Qt::SwipeNativeGesture** Swipe angle in
    degrees.macOS: Configurable in trackpad settings.
    **Qt::PanNativeGesture**
    Displacement delta in pixels.Wayland: Three or more fingers moving as a
    group, in any direction.

    In addition, BeginNativeGesture and EndNativeGesture are sent before and
    after gesture event streams:

    BeginNativeGesture ZoomNativeGesture ZoomNativeGesture ZoomNativeGesture
    EndNativeGesture

    The event stream may include interleaved gestures of different types: for
    example the two-finger pinch gesture generates a stream of Zoom and Rotate
    events, and PanNativeGesture may sometimes be interleaved with those,
    depending on the platform.

    Other types are standalone events: SmartZoomNativeGesture and
    SwipeNativeGesture occur only once each time the gesture is detected.

    **Note:** On a touchpad, moving two fingers as a group (the two-finger flick
    gesture) is usually reserved for scrolling; in that case, Qt generates
    QWheelEvents. This is the reason that three or more fingers are needed to
    generate a PanNativeGesture.

    **See also** **Qt::NativeGestureType** , **QGestureEvent** , and
    **QWheelEvent** .
    """

    @typing.overload
    def __init__(
        self,
        type: QtCore.Qt.NativeGestureType,
        dev: "QPointingDevice",
        fingerCount: int,
        localPos: QtCore.QPointF,
        scenePos: QtCore.QPointF,
        globalPos: QtCore.QPointF,
        value: float,
        delta: QtCore.QPointF,
        sequenceId: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnativegestureevent.html#QNativeGestureEvent-3

        **[since 6.2]
        QNativeGestureEvent::QNativeGestureEvent(Qt::NativeGestureType type ,
        const QPointingDevice * device , int fingerCount , const QPointF &
        localPos , const QPointF & scenePos , const QPointF & globalPos , qreal
        value , const QPointF & delta , quint64 sequenceId = UINT64_MAX)**

        Constructs a native gesture event of type **type** originating from
        **device** describing a gesture at **scenePos** in which **fingerCount**
        fingers are involved.

        The points **localPos** , **scenePos** and **globalPos** specify the
        gesture position relative to the receiving widget or item, window, and
        screen or desktop, respectively.

        **value** has a gesture-dependent interpretation: for
        RotateNativeGesture or SwipeNativeGesture, it's an angle in degrees. For
        ZoomNativeGesture, **value** is an incremental scaling factor, usually
        much less than 1, indicating that the target item should have its scale
        adjusted like this: item.scale = item.scale * (1 + event.value)

        For PanNativeGesture, **delta** gives the distance in pixels that the
        viewport, widget or item should be moved or panned.

        **Note:** The **delta** is stored in single precision (**QVector2D** ),
        so **delta** () may return slightly different values in some cases. This
        is subject to change in future versions of Qt.

        This function was introduced in Qt 6.2.
        """
        ...

    @typing.overload
    def __init__(
        self,
        type: QtCore.Qt.NativeGestureType,
        dev: "QPointingDevice",
        localPos: QtCore.QPointF,
        scenePos: QtCore.QPointF,
        globalPos: QtCore.QPointF,
        value: float,
        sequenceId: int,
        intArgument: int,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnativegestureevent.html#QNativeGestureEvent-3

        **[since 6.2]
        QNativeGestureEvent::QNativeGestureEvent(Qt::NativeGestureType type ,
        const QPointingDevice * device , int fingerCount , const QPointF &
        localPos , const QPointF & scenePos , const QPointF & globalPos , qreal
        value , const QPointF & delta , quint64 sequenceId = UINT64_MAX)**

        Constructs a native gesture event of type **type** originating from
        **device** describing a gesture at **scenePos** in which **fingerCount**
        fingers are involved.

        The points **localPos** , **scenePos** and **globalPos** specify the
        gesture position relative to the receiving widget or item, window, and
        screen or desktop, respectively.

        **value** has a gesture-dependent interpretation: for
        RotateNativeGesture or SwipeNativeGesture, it's an angle in degrees. For
        ZoomNativeGesture, **value** is an incremental scaling factor, usually
        much less than 1, indicating that the target item should have its scale
        adjusted like this: item.scale = item.scale * (1 + event.value)

        For PanNativeGesture, **delta** gives the distance in pixels that the
        viewport, widget or item should be moved or panned.

        **Note:** The **delta** is stored in single precision (**QVector2D** ),
        so **delta** () may return slightly different values in some cases. This
        is subject to change in future versions of Qt.

        This function was introduced in Qt 6.2.
        """
        ...

    def delta(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qnativegestureevent.html#delta

        **[since 6.2] QPointF QNativeGestureEvent::delta() const**

        Returns the distance moved since the previous event, in pixels. A Pan
        gesture provides the distance in pixels by which the target widget, item
        or viewport contents should be moved.

        This function was introduced in Qt 6.2.

        **See also** **QPanGesture::delta** ().
        """
        ...

    def fingerCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qnativegestureevent.html#fingerCount

        **[since 6.2] int QNativeGestureEvent::fingerCount() const**

        Returns the number of fingers participating in the gesture, if known.
        When **gestureType** () is **Qt::BeginNativeGesture**  or
        **Qt::EndNativeGesture** , often this information is unknown, and
        fingerCount() returns `0`.

        This function was introduced in Qt 6.2.
        """
        ...

    def clone(self) -> "QNativeGestureEvent":
        ...

    def value(self) -> float:
        """
        https://doc.qt.io/qt-6/qnativegestureevent.html#value

        **[since 5.2] qreal QNativeGestureEvent::value() const**

        Returns the gesture value. The value should be interpreted based on the
        gesture type. For example, a Zoom gesture provides a scale factor delta
        while a Rotate gesture provides a rotation delta.

        This function was introduced in Qt 5.2.

        **See also** **QNativeGestureEvent**  and **gestureType** ().
        """
        ...

    def gestureType(self) -> QtCore.Qt.NativeGestureType:
        """
        https://doc.qt.io/qt-6/qnativegestureevent.html#gestureType

        **[since 5.2] Qt::NativeGestureType QNativeGestureEvent::gestureType()
        const**

        Returns the gesture type.

        This function was introduced in Qt 5.2.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QTreeWidget(QTreeView):
    """
    https://doc.qt.io/qt-6/qtreewidget.html

    **Detailed Description**

    ![](images/windows-treeview.png)

    The QTreeWidget class is a convenience class that provides a standard tree
    widget with a classic item-based interface similar to that used by the
    **QListView**  class in Qt 3. This class is based on Qt's Model/View
    architecture and uses a default model to hold items, each of which is a
    **QTreeWidgetItem** .

    Developers who do not need the flexibility of the Model/View framework can
    use this class to create simple hierarchical lists very easily. A more
    flexible approach involves combining a **QTreeView**  with a standard item
    model. This allows the storage of data to be separated from its
    representation.

    In its simplest form, a tree widget can be constructed in the following way:

    **QTreeWidget**  *treeWidget = new **QTreeWidget** ();
    treeWidget->setColumnCount(1);
        **QList** <**QTreeWidgetItem**  *> items;
    for (int i = 0; i < 10; ++i)
            items.append(new **QTreeWidgetItem**
    (static_cast<**QTreeWidget**  *>(nullptr), **QStringList** (**QString**
    ("item: %1").arg(i))));
        treeWidget->insertTopLevelItems(0, items);

    Before items can be added to the tree widget, the number of columns must be
    set with **setColumnCount** (). This allows each item to have one or more
    labels or other decorations. The number of columns in use can be found with
    the **columnCount** () function.

    The tree can have a header that contains a section for each column in the
    widget. It is easiest to set up the labels for each section by supplying a
    list of strings with **setHeaderLabels** (), but a custom header can be
    constructed with a **QTreeWidgetItem**  and inserted into the tree with the
    **setHeaderItem** () function.

    The items in the tree can be sorted by column according to a predefined sort
    order. If sorting is enabled, the user can sort the items by clicking on a
    column header. Sorting can be enabled or disabled by calling
    **setSortingEnabled** (). The **isSortingEnabled** () function indicates
    whether sorting is enabled.

    **See also** **QTreeWidgetItem** , **QTreeWidgetItemIterator** ,
    **QTreeView** , **Model/View Programming** , and **Settings Editor Example**
    .
    """

    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#QTreeWidget

        **QTreeWidget::QTreeWidget(QWidget * parent = nullptr)**

        Constructs a tree widget with the given **parent**.
        """
        ...

    def isPersistentEditorOpen(self, item: QTreeWidgetItem, column: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#isPersistentEditorOpen

        **[since 5.10] bool QTreeWidget::isPersistentEditorOpen(QTreeWidgetItem
        * item , int column = 0) const**

        Returns whether a persistent editor is open for item **item** in column
        **column**.

        This function was introduced in Qt 5.10.

        **See also** **openPersistentEditor** () and **closePersistentEditor**
        ().
        """
        ...

    def setSelectionModel(self, selectionModel: QtCore.QItemSelectionModel) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#setSelectionModel

        **[override virtual] void
        QTreeWidget::setSelectionModel(QItemSelectionModel * selectionModel )**

        Reimplements: **QTreeView::setSelectionModel** (QItemSelectionModel
        *selectionModel).
        """
        ...

    def removeItemWidget(self, item: QTreeWidgetItem, column: int) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#removeItemWidget

        **void QTreeWidget::removeItemWidget(QTreeWidgetItem * item , int column
        )**

        Removes the widget set in the given **item** in the given **column**.
        """
        ...

    def itemBelow(self, item: QTreeWidgetItem) -> QTreeWidgetItem:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#itemBelow

        **QTreeWidgetItem *QTreeWidget::itemBelow(const QTreeWidgetItem * item )
        const**

        Returns the item visually below the given **item**.
        """
        ...

    def itemAbove(self, item: QTreeWidgetItem) -> QTreeWidgetItem:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#itemAbove

        **QTreeWidgetItem *QTreeWidget::itemAbove(const QTreeWidgetItem * item )
        const**

        Returns the item above the given **item**.
        """
        ...

    def setHeaderLabel(self, alabel: str) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#setHeaderLabel

        **void QTreeWidget::setHeaderLabel(const QString & label )**

        Same as **setHeaderLabels** (**QStringList** ( **label** )).
        """
        ...

    def invisibleRootItem(self) -> QTreeWidgetItem:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#invisibleRootItem

        **QTreeWidgetItem *QTreeWidget::invisibleRootItem() const**

        Returns the tree widget's invisible root item.

        The invisible root item provides access to the tree widget's top-level
        items through the **QTreeWidgetItem**  API, making it possible to write
        functions that can treat top-level items and their children in a uniform
        way; for example, recursive functions.
        """
        ...

    def dropEvent(self, event: QtGui.QDropEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#dropEvent

        **[override virtual protected] void QTreeWidget::dropEvent(QDropEvent *
        event )**

        Reimplements: **QAbstractItemView::dropEvent** (QDropEvent *event).
        """
        ...

    def event(self, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#event

        **[override virtual protected] bool QTreeWidget::event(QEvent * e )**

        Reimplements: **QAbstractItemView::event** (QEvent *event).
        """
        ...

    def itemFromIndex(self, index: QtCore.QModelIndex) -> QTreeWidgetItem:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#itemFromIndex

        **QTreeWidgetItem *QTreeWidget::itemFromIndex(const QModelIndex & index
        ) const**

        Returns a pointer to the **QTreeWidgetItem**  associated with the given
        **index**.

        **See also** **indexFromItem** ().
        """
        ...

    def indexFromItem(
        self, item: QTreeWidgetItem, column: int = ...
    ) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#indexFromItem

        **QModelIndex QTreeWidget::indexFromItem(const QTreeWidgetItem * item ,
        int column = 0) const**

        Returns the **QModelIndex**  associated with the given **item** in the
        given **column**.

        **Note:** In Qt versions prior to 5.7, this function took a non-`const`
        **item**.

        **See also** **itemFromIndex** () and **topLevelItem** ().
        """
        ...

    def supportedDropActions(self) -> QtCore.Qt.DropAction:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#supportedDropActions

        **[virtual protected] Qt::DropActions
        QTreeWidget::supportedDropActions() const**

        Returns the drop actions supported by this view.

        **See also** **Qt::DropActions** .
        """
        ...

    def dropMimeData(
        self,
        parent: QTreeWidgetItem,
        index: int,
        data: QtCore.QMimeData,
        action: QtCore.Qt.DropAction,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#dropMimeData

        **[virtual protected] bool QTreeWidget::dropMimeData(QTreeWidgetItem *
        parent , int index , const QMimeData * data , Qt::DropAction action )**

        Handles the **data** supplied by a drag and drop operation that ended
        with the given **action** in the **index** in the given **parent** item.

        The default implementation returns `true` if the drop was successfully
        handled by decoding the mime data and inserting it into the model;
        otherwise it returns `false`.

        **See also** **supportedDropActions** ().
        """
        ...

    def mimeData(self, items: typing.Iterable[QTreeWidgetItem]) -> QtCore.QMimeData:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#mimeData

        **[virtual protected] QMimeData *QTreeWidget::mimeData(const
        QList<QTreeWidgetItem *> & items ) const**

        Returns an object that contains a serialized description of the
        specified **items**. The format used to describe the items is obtained
        from the **mimeTypes** () function.

        If the list of items is empty, `nullptr` is returned rather than a
        serialized empty list.
        """
        ...

    def mimeTypes(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#mimeTypes

        **[virtual protected] QStringList QTreeWidget::mimeTypes() const**

        Returns a list of MIME types that can be used to describe a list of
        treewidget items.

        **See also** **mimeData** ().
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#clear

        **[slot] void QTreeWidget::clear()**

        Clears the tree widget by removing all of its items and selections.

        **Note:** Since each item is removed from the tree widget before being
        deleted, the return value of **QTreeWidgetItem::treeWidget** () will be
        invalid when called from an item's destructor.

        **See also** **takeTopLevelItem** (), **topLevelItemCount** (), and
        **columnCount** ().
        """
        ...

    def collapseItem(self, item: QTreeWidgetItem) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#collapseItem

        **[slot] void QTreeWidget::collapseItem(const QTreeWidgetItem * item )**

        Closes the **item**. This causes the tree containing the item's children
        to be collapsed.

        **See also** **expandItem** (), **currentItem** (), **itemAt** (), and
        **topLevelItem** ().
        """
        ...

    def expandItem(self, item: QTreeWidgetItem) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#expandItem

        **[slot] void QTreeWidget::expandItem(const QTreeWidgetItem * item )**

        Expands the **item**. This causes the tree containing the item's
        children to be expanded.

        **See also** **collapseItem** (), **currentItem** (), **itemAt** (),
        **topLevelItem** (), and **itemExpanded** ().
        """
        ...

    def scrollToItem(
        self, item: QTreeWidgetItem, hint: QAbstractItemView.ScrollHint = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#scrollToItem

        **[slot] void QTreeWidget::scrollToItem(const QTreeWidgetItem * item ,
        QAbstractItemView::ScrollHint hint = EnsureVisible)**

        Ensures that the **item** is visible, scrolling the view if necessary
        using the specified **hint**.

        **See also** **currentItem** (), **itemAt** (), and **topLevelItem** ().
        """
        ...

    def findItems(
        self, text: str, flags: QtCore.Qt.MatchFlag, column: int = ...
    ) -> typing.List[QTreeWidgetItem]:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#findItems

        **QList<QTreeWidgetItem *> QTreeWidget::findItems(const QString & text ,
        Qt::MatchFlags flags , int column = 0) const**

        Returns a list of items that match the given **text** , using the given
        **flags** , in the given **column**.
        """
        ...

    def selectedItems(self) -> typing.List[QTreeWidgetItem]:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#selectedItems

        **QList<QTreeWidgetItem *> QTreeWidget::selectedItems() const**

        Returns a list of all selected non-hidden items.

        **See also** **itemSelectionChanged** ().
        """
        ...

    def setItemWidget(
        self, item: QTreeWidgetItem, column: int, widget: QWidget
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#setItemWidget

        **void QTreeWidget::setItemWidget(QTreeWidgetItem * item , int column ,
        QWidget * widget )**

        Sets the given **widget** to be displayed in the cell specified by the
        given **item** and **column**.

        The given **widget** 's **autoFillBackground**  property must be set to
        true, otherwise the widget's background will be transparent, showing
        both the model data and the tree widget item.

        This function should only be used to display static content in the place
        of a tree widget item. If you want to display custom dynamic content or
        implement a custom editor widget, use **QTreeView**  and subclass
        **QStyledItemDelegate**  instead.

        This function cannot be called before the item hierarchy has been set
        up, i.e., the **QTreeWidgetItem**  that will hold **widget** must have
        been added to the view before **widget** is set.

        **Note:** The tree takes ownership of the widget.

        **See also** **itemWidget** () and **Delegate Classes** .
        """
        ...

    def itemWidget(self, item: QTreeWidgetItem, column: int) -> QWidget:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#itemWidget

        **QWidget *QTreeWidget::itemWidget(QTreeWidgetItem * item , int column )
        const**

        Returns the widget displayed in the cell specified by **item** and the
        given **column**.

        **See also** **setItemWidget** ().
        """
        ...

    def closePersistentEditor(self, item: QTreeWidgetItem, column: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#closePersistentEditor

        **void QTreeWidget::closePersistentEditor(QTreeWidgetItem * item , int
        column = 0)**

        Closes the persistent editor for the **item** in the given **column**.

        This function has no effect if no persistent editor is open for this
        combination of item and column.

        **See also** **openPersistentEditor** () and **isPersistentEditorOpen**
        ().
        """
        ...

    def openPersistentEditor(self, item: QTreeWidgetItem, column: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#openPersistentEditor

        **void QTreeWidget::openPersistentEditor(QTreeWidgetItem * item , int
        column = 0)**

        Opens a persistent editor for the **item** in the given **column**.

        **See also** **closePersistentEditor** () and **isPersistentEditorOpen**
        ().
        """
        ...

    def editItem(self, item: QTreeWidgetItem, column: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#editItem

        **void QTreeWidget::editItem(QTreeWidgetItem * item , int column = 0)**

        Starts editing the **item** in the given **column** if it is editable.
        """
        ...

    def sortItems(self, column: int, order: QtCore.Qt.SortOrder) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#sortItems

        **void QTreeWidget::sortItems(int column , Qt::SortOrder order )**

        Sorts the items in the widget in the specified **order** by the values
        in the given **column**.

        **See also** **sortColumn** ().
        """
        ...

    def sortColumn(self) -> int:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#sortColumn

        **int QTreeWidget::sortColumn() const**

        Returns the column used to sort the contents of the widget.

        **See also** **sortItems** ().
        """
        ...

    def visualItemRect(self, item: QTreeWidgetItem) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#visualItemRect

        **QRect QTreeWidget::visualItemRect(const QTreeWidgetItem * item )
        const**

        Returns the rectangle on the viewport occupied by the item at **item**.

        **See also** **itemAt** ().
        """
        ...

    @typing.overload
    def itemAt(self, p: QtCore.QPoint) -> QTreeWidgetItem:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#itemAt

        **QTreeWidgetItem *QTreeWidget::itemAt(const QPoint & p ) const**

        Returns a pointer to the item at the coordinates **p**. The coordinates
        are relative to the tree widget's **viewport** ().

        **See also** **visualItemRect** ().
        """
        ...

    @typing.overload
    def itemAt(self, ax: int, ay: int) -> QTreeWidgetItem:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#itemAt-1

        **QTreeWidgetItem *QTreeWidget::itemAt(int x , int y ) const**

        This is an overloaded function.

        Returns a pointer to the item at the coordinates ( **x** , **y** ). The
        coordinates are relative to the tree widget's **viewport** ().
        """
        ...

    @typing.overload
    def setCurrentItem(self, item: QTreeWidgetItem) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#setCurrentItem

        **void QTreeWidget::setCurrentItem(QTreeWidgetItem * item )**

        Sets the current **item** in the tree widget.

        Unless the selection mode is **NoSelection** , the item is also
        selected.

        **See also** **currentItem** () and **currentItemChanged** ().
        """
        ...

    @typing.overload
    def setCurrentItem(self, item: QTreeWidgetItem, column: int) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#setCurrentItem-1

        **void QTreeWidget::setCurrentItem(QTreeWidgetItem * item , int column
        )**

        Sets the current **item** in the tree widget and the current column to
        **column**.

        **See also** **currentItem** ().
        """
        ...

    @typing.overload
    def setCurrentItem(
        self,
        item: QTreeWidgetItem,
        column: int,
        command: QtCore.QItemSelectionModel.SelectionFlag,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#setCurrentItem-2

        **void QTreeWidget::setCurrentItem(QTreeWidgetItem * item , int column ,
        QItemSelectionModel::SelectionFlags command )**

        Sets the current **item** in the tree widget and the current column to
        **column** , using the given **command**.

        **See also** **currentItem** ().
        """
        ...

    def currentColumn(self) -> int:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#currentColumn

        **int QTreeWidget::currentColumn() const**

        Returns the current column in the tree widget.

        **See also** **setCurrentItem** () and **columnCount** ().
        """
        ...

    def currentItem(self) -> QTreeWidgetItem:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#currentItem

        **QTreeWidgetItem *QTreeWidget::currentItem() const**

        Returns the current item in the tree widget.

        **See also** **setCurrentItem** () and **currentItemChanged** ().
        """
        ...

    def setHeaderLabels(self, labels: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#setHeaderLabels

        **void QTreeWidget::setHeaderLabels(const QStringList & labels )**

        Adds a column in the header for each item in the **labels** list, and
        sets the label for each column.

        Note that setHeaderLabels() won't remove existing columns.

        **See also** **setHeaderItem** () and **setHeaderLabel** ().
        """
        ...

    def setHeaderItem(self, item: QTreeWidgetItem) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#setHeaderItem

        **void QTreeWidget::setHeaderItem(QTreeWidgetItem * item )**

        Sets the header **item** for the tree widget. The label for each column
        in the header is supplied by the corresponding label in the item.

        The tree widget takes ownership of the item.

        **See also** **headerItem** () and **setHeaderLabels** ().
        """
        ...

    def headerItem(self) -> QTreeWidgetItem:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#headerItem

        **QTreeWidgetItem *QTreeWidget::headerItem() const**

        Returns the item used for the tree widget's header.

        **See also** **setHeaderItem** ().
        """
        ...

    def addTopLevelItems(self, items: typing.Iterable[QTreeWidgetItem]) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#addTopLevelItems

        **void QTreeWidget::addTopLevelItems(const QList<QTreeWidgetItem *> &
        items )**

        Appends the list of **items** as a top-level items in the widget.

        **See also** **insertTopLevelItems** ().
        """
        ...

    def insertTopLevelItems(
        self, index: int, items: typing.Iterable[QTreeWidgetItem]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#insertTopLevelItems

        **void QTreeWidget::insertTopLevelItems(int index , const
        QList<QTreeWidgetItem *> & items )**

        Inserts the list of **items** at **index** in the top level in the view.

        Items that have already been inserted somewhere else won't be inserted.

        **See also** **addTopLevelItems** ().
        """
        ...

    def indexOfTopLevelItem(self, item: QTreeWidgetItem) -> int:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#indexOfTopLevelItem

        **int QTreeWidget::indexOfTopLevelItem(QTreeWidgetItem * item ) const**

        Returns the index of the given top-level **item** , or -1 if the item
        cannot be found.

        **See also** **sortItems** () and **topLevelItemCount** ().
        """
        ...

    def takeTopLevelItem(self, index: int) -> QTreeWidgetItem:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#takeTopLevelItem

        **QTreeWidgetItem *QTreeWidget::takeTopLevelItem(int index )**

        Removes the top-level item at the given **index** in the tree and
        returns it, otherwise returns `nullptr`;

        **See also** **insertTopLevelItem** (), **topLevelItem** (), and
        **topLevelItemCount** ().
        """
        ...

    def addTopLevelItem(self, item: QTreeWidgetItem) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#addTopLevelItem

        **void QTreeWidget::addTopLevelItem(QTreeWidgetItem * item )**

        Appends the **item** as a top-level item in the widget.

        **See also** **insertTopLevelItem** ().
        """
        ...

    def insertTopLevelItem(self, index: int, item: QTreeWidgetItem) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#insertTopLevelItem

        **void QTreeWidget::insertTopLevelItem(int index , QTreeWidgetItem *
        item )**

        Inserts the **item** at **index** in the top level in the view.

        If the item has already been inserted somewhere else it won't be
        inserted.

        **See also** **addTopLevelItem** () and **columnCount** ().
        """
        ...

    def topLevelItemCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#topLevelItemCount-prop

        **[read-only] topLevelItemCount : const int**

        This property holds the number of top-level items

        By default, this property has a value of 0.

        **Access functions:**

        int **topLevelItemCount** () const

        **See also** **columnCount** () and **currentItem** ().

        **Member Function Documentation**
        """
        ...

    def topLevelItem(self, index: int) -> QTreeWidgetItem:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#topLevelItem

        **QTreeWidgetItem *QTreeWidget::topLevelItem(int index ) const**

        Returns the top level item at the given **index** , or `nullptr` if the
        item does not exist.

        **See also** **topLevelItemCount** () and **insertTopLevelItem** ().
        """
        ...

    def setColumnCount(self, columns: int) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#columnCount-prop

        **columnCount : int**

        This property holds the number of columns displayed in the tree widget

        By default, this property has a value of 1.

        **Access functions:**

        int **columnCount** () const
        void **setColumnCount** (int **columns**
        )
        """
        ...

    def columnCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#columnCount-prop

        **columnCount : int**

        This property holds the number of columns displayed in the tree widget

        By default, this property has a value of 1.

        **Access functions:**

        int **columnCount** () const
        void **setColumnCount** (int **columns**
        )
        """
        ...

    @property
    def currentItemChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#currentItemChanged

        **[signal] void QTreeWidget::currentItemChanged(QTreeWidgetItem *
        current , QTreeWidgetItem * previous )**

        This signal is emitted when the current item changes. The current item
        is specified by **current** , and this replaces the **previous** current
        item.

        **See also** **setCurrentItem** ().
        """
        ...

    @property
    def itemActivated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#itemActivated

        **[signal] void QTreeWidget::itemActivated(QTreeWidgetItem * item , int
        column )**

        This signal is emitted when the user activates an item by single- or
        double-clicking (depending on the platform, i.e. on the
        **QStyle::SH_ItemView_ActivateItemOnSingleClick**  style hint) or
        pressing a special key (e.g., **Enter** ).

        The specified **item** is the item that was clicked, or `nullptr` if no
        item was clicked. The **column** is the item's column that was clicked,
        or -1 if no item was clicked.
        """
        ...

    @property
    def itemChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#itemChanged

        **[signal] void QTreeWidget::itemChanged(QTreeWidgetItem * item , int
        column )**

        This signal is emitted when the contents of the **column** in the
        specified **item** changes.
        """
        ...

    @property
    def itemClicked(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#itemClicked

        **[signal] void QTreeWidget::itemClicked(QTreeWidgetItem * item , int
        column )**

        This signal is emitted when the user clicks inside the widget.

        The specified **item** is the item that was clicked. The **column** is
        the item's column that was clicked. If no item was clicked, no signal
        will be emitted.
        """
        ...

    @property
    def itemCollapsed(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#itemCollapsed

        **[signal] void QTreeWidget::itemCollapsed(QTreeWidgetItem * item )**

        This signal is emitted when the specified **item** is collapsed so that
        none of its children are displayed.

        **Note:** This signal will not be emitted if an item changes its state
        when **collapseAll** () is invoked.

        **See also** **QTreeWidgetItem::isExpanded** (), **itemExpanded** (),
        and **collapseItem** ().
        """
        ...

    @property
    def itemDoubleClicked(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#itemDoubleClicked

        **[signal] void QTreeWidget::itemDoubleClicked(QTreeWidgetItem * item ,
        int column )**

        This signal is emitted when the user double clicks inside the widget.

        The specified **item** is the item that was clicked, or `nullptr` if no
        item was clicked. The **column** is the item's column that was clicked.
        If no item was double clicked, no signal will be emitted.
        """
        ...

    @property
    def itemEntered(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#itemEntered

        **[signal] void QTreeWidget::itemEntered(QTreeWidgetItem * item , int
        column )**

        This signal is emitted when the mouse cursor enters an **item** over the
        specified **column**. **QTreeWidget**  mouse tracking needs to be
        enabled for this feature to work.
        """
        ...

    @property
    def itemExpanded(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#itemExpanded

        **[signal] void QTreeWidget::itemExpanded(QTreeWidgetItem * item )**

        This signal is emitted when the specified **item** is expanded so that
        all of its children are displayed.

        **Note:** This signal will not be emitted if an item changes its state
        when **expandAll** () is invoked.

        **See also** **QTreeWidgetItem::isExpanded** (), **itemCollapsed** (),
        and **expandItem** ().
        """
        ...

    @property
    def itemPressed(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#itemPressed

        **[signal] void QTreeWidget::itemPressed(QTreeWidgetItem * item , int
        column )**

        This signal is emitted when the user presses a mouse button inside the
        widget.

        The specified **item** is the item that was clicked, or `nullptr` if no
        item was clicked. The **column** is the item's column that was clicked,
        or -1 if no item was clicked.
        """
        ...

    @property
    def itemSelectionChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtreewidget.html#itemSelectionChanged

        **[signal] void QTreeWidget::itemSelectionChanged()**

        This signal is emitted when the selection changes in the tree widget.
        The current selection can be found with **selectedItems** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6.QtPrintSupport import *
import enum


class QPrintEngine(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qprintengine.html

    **Detailed Description**

    The common case when creating your own print engine is to derive from both
    **QPaintEngine**  and QPrintEngine. Various properties of a print engine are
    given with **property** () and set with **setProperty** ().

    **See also** **QPaintEngine** .
    """

    class PrintEnginePropertyKey(enum.Enum):
        PPK_CollateCopies: QPrintEngine = ...
        PPK_ColorMode: QPrintEngine = ...
        PPK_Creator: QPrintEngine = ...
        PPK_DocumentName: QPrintEngine = ...
        PPK_FullPage: QPrintEngine = ...
        PPK_NumberOfCopies: QPrintEngine = ...
        PPK_Orientation: QPrintEngine = ...
        PPK_OutputFileName: QPrintEngine = ...
        PPK_PageOrder: QPrintEngine = ...
        PPK_PageRect: QPrintEngine = ...
        PPK_PageSize: QPrintEngine = ...
        PPK_PaperRect: QPrintEngine = ...
        PPK_PaperSource: QPrintEngine = ...
        PPK_PrinterName: QPrintEngine = ...
        PPK_PrinterProgram: QPrintEngine = ...
        PPK_Resolution: QPrintEngine = ...
        PPK_SelectionOption: QPrintEngine = ...
        PPK_SupportedResolutions: QPrintEngine = ...
        PPK_WindowsPageSize: QPrintEngine = ...
        PPK_FontEmbedding: QPrintEngine = ...
        PPK_Duplex: QPrintEngine = ...
        PPK_PaperSources: QPrintEngine = ...
        PPK_CustomPaperSize: QPrintEngine = ...
        PPK_PageMargins: QPrintEngine = ...
        PPK_PaperSize: QPrintEngine = ...
        PPK_CopyCount: QPrintEngine = ...
        PPK_SupportsMultipleCopies: QPrintEngine = ...
        PPK_PaperName: QPrintEngine = ...
        PPK_QPageSize: QPrintEngine = ...
        PPK_QPageMargins: QPrintEngine = ...
        PPK_QPageLayout: QPrintEngine = ...
        PPK_CustomBase: QPrintEngine = ...

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QPrintEngine") -> None:
        ...

    def printerState(self) -> "QPrinter.PrinterState":
        """
        https://doc.qt.io/qt-6/qprintengine.html#printerState

        **[pure virtual] QPrinter::PrinterState QPrintEngine::printerState()
        const**

        Returns the current state of the printer being used by the print engine.
        """
        ...

    def metric(self, a0: QtGui.QPaintDevice.PaintDeviceMetric) -> int:
        """
        https://doc.qt.io/qt-6/qprintengine.html#metric

        **[pure virtual] int
        QPrintEngine::metric(QPaintDevice::PaintDeviceMetric id ) const**

        Returns the metric for the given **id**.
        """
        ...

    def abort(self) -> bool:
        """
        https://doc.qt.io/qt-6/qprintengine.html#abort

        **[pure virtual] bool QPrintEngine::abort()**

        Instructs the print engine to abort the printing process. Returns true
        if successful; otherwise returns `false`.
        """
        ...

    def newPage(self) -> bool:
        """
        https://doc.qt.io/qt-6/qprintengine.html#newPage

        **[pure virtual] bool QPrintEngine::newPage()**

        Instructs the print engine to start a new page. Returns `true` if the
        printer was able to create the new page; otherwise returns `false`.
        """
        ...

    def property(self, key: "QPrintEngine.PrintEnginePropertyKey") -> typing.Any:
        """
        https://doc.qt.io/qt-6/qprintengine.html#property

        **[pure virtual] QVariant
        QPrintEngine::property(QPrintEngine::PrintEnginePropertyKey key )
        const**

        Returns the print engine's property specified by **key**.

        **See also** **setProperty** ().
        """
        ...

    def setProperty(
        self, key: "QPrintEngine.PrintEnginePropertyKey", value: typing.Any
    ) -> None:
        """
        https://doc.qt.io/qt-6/qprintengine.html#setProperty

        **[pure virtual] void
        QPrintEngine::setProperty(QPrintEngine::PrintEnginePropertyKey key ,
        const QVariant & value )**

        Sets the print engine's property specified by **key** to the given
        **value**.

        **See also** **property** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtHelp import *


class QHelpSearchEngine(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qhelpsearchengine.html

    **Detailed Description**

    Before the search engine can be used, one has to instantiate at least a
    **QHelpEngineCore**  object that needs to be passed to the search engines
    constructor. This is required as the search engine needs to be connected to
    the help engines setupFinished() signal to know when it can start to index
    documentation.

    After starting the indexing process the signal **indexingStarted** () is
    emitted and on the end of the indexing process the **indexingFinished** ()
    is emitted. To stop the indexing one can call **cancelIndexing** ().

    When the indexing process has finished, the search engine can be used to
    search through the index for a given term using the search() function. When
    the search input is passed to the search engine, the **searchingStarted** ()
    signal is emitted. When the search finishes, the **searchingFinished** ()
    signal is emitted. The search process can be stopped by calling
    **cancelSearching** ().

    If the search succeeds, **searchingFinished** () is called with the search
    result count to fetch the search results from the search engine. Calling the
    **searchResults** () function with a range returns a list of
    **QHelpSearchResult**  objects within the range. The results consist of the
    document title and URL, as well as a snippet from the document that contains
    the best match for the search input.

    To display the given search results use the **QHelpSearchResultWidget**  or
    build up your own one if you need more advanced functionality. Note that the
    **QHelpSearchResultWidget**  can not be instantiated directly, you must
    retrieve the widget from the search engine in use as all connections will be
    established for you by the widget itself.
    """

    def __init__(
        self, helpEngine: QHelpEngineCore, parent: typing.Optional[QtCore.QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qhelpsearchengine.html#QHelpSearchEngine

        **QHelpSearchEngine::QHelpSearchEngine(QHelpEngineCore * helpEngine ,
        QObject * parent = nullptr)**

        Constructs a new search engine with the given **parent**. The search
        engine uses the given **helpEngine** to access the documentation that
        needs to be indexed. The **QHelpEngine** 's setupFinished() signal is
        automatically connected to the QHelpSearchEngine's indexing function, so
        that new documentation will be indexed after the signal is emitted.
        """
        ...

    def search(self, searchInput: str) -> None:
        """
        https://doc.qt.io/qt-6/qhelpsearchengine.html#search-1

        **[slot, since 5.9] void QHelpSearchEngine::search(const QString &
        searchInput )**

        Starts the search process using the given search phrase **searchInput**.

        The phrase may consist of several words. By default, the search engine
        returns the list of documents that contain all the specified words. The
        phrase may contain any combination of the logical operators AND, OR, and
        NOT. The operator must be written in all capital letters, otherwise it
        will be considered a part of the search phrase.

        If double quotation marks are used to group the words, the search engine
        will search for an exact match of the quoted phrase.

        For more information about the text query syntax, see **SQLite FTS5
        Extension** .

        This function was introduced in Qt 5.9.
        """
        ...

    def searchInput(self) -> str:
        """
        https://doc.qt.io/qt-6/qhelpsearchengine.html#searchInput

        **[since 5.9] QString QHelpSearchEngine::searchInput() const**

        Returns the phrase that was last searched for.

        This function was introduced in Qt 5.9.
        """
        ...

    def searchResults(self, start: int, end: int) -> typing.List["QHelpSearchResult"]:
        """
        https://doc.qt.io/qt-6/qhelpsearchengine.html#searchResults

        **[since 5.9] QList<QHelpSearchResult>
        QHelpSearchEngine::searchResults(int start , int end ) const**

        Returns a list of search results within the range from the index
        specified by **start** to the index specified by **end**.

        This function was introduced in Qt 5.9.
        """
        ...

    def searchResultCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qhelpsearchengine.html#searchResultCount

        **[since 5.9] int QHelpSearchEngine::searchResultCount() const**

        Returns the number of results the search engine found.

        This function was introduced in Qt 5.9.
        """
        ...

    def cancelSearching(self) -> None:
        """
        https://doc.qt.io/qt-6/qhelpsearchengine.html#cancelSearching

        **[slot] void QHelpSearchEngine::cancelSearching()**

        Stops the search process.
        """
        ...

    def cancelIndexing(self) -> None:
        """
        https://doc.qt.io/qt-6/qhelpsearchengine.html#cancelIndexing

        **[slot] void QHelpSearchEngine::cancelIndexing()**

        Stops the indexing process.
        """
        ...

    def reindexDocumentation(self) -> None:
        """
        https://doc.qt.io/qt-6/qhelpsearchengine.html#reindexDocumentation

        **[slot] void QHelpSearchEngine::reindexDocumentation()**

        Forces the search engine to reindex all documentation files.
        """
        ...

    def resultWidget(self) -> "QHelpSearchResultWidget":
        """
        https://doc.qt.io/qt-6/qhelpsearchengine.html#resultWidget

        **QHelpSearchResultWidget *QHelpSearchEngine::resultWidget()**

        Returns a widget that can hold and display the search results.
        """
        ...

    def queryWidget(self) -> "QHelpSearchQueryWidget":
        """
        https://doc.qt.io/qt-6/qhelpsearchengine.html#queryWidget

        **QHelpSearchQueryWidget *QHelpSearchEngine::queryWidget()**

        Returns a widget to use as input widget. Depending on your search engine
        configuration you will get a different widget with more or less
        subwidgets.
        """
        ...

    @property
    def indexingFinished(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qhelpsearchengine.html#indexingFinished

        **[signal] void QHelpSearchEngine::indexingFinished()**

        This signal is emitted when the indexing process is complete.
        """
        ...

    @property
    def indexingStarted(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qhelpsearchengine.html#indexingStarted

        **[signal] void QHelpSearchEngine::indexingStarted()**

        This signal is emitted when indexing process is started.
        """
        ...

    @property
    def searchingFinished(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qhelpsearchengine.html#searchingFinished

        **[signal] void QHelpSearchEngine::searchingFinished(int
        searchResultCount )**

        This signal is emitted when the search process is complete. The search
        result count is stored in **searchResultCount**.
        """
        ...

    @property
    def searchingStarted(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qhelpsearchengine.html#searchingStarted

        **[signal] void QHelpSearchEngine::searchingStarted()**

        This signal is emitted when the search process is started.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QStyleOptionTab(QStyleOption):
    """
    https://doc.qt.io/qt-6/qstyleoptiontab.html

    **Detailed Description**

    The QStyleOptionTab class is used for drawing several built-in Qt widgets
    including **QTabBar**  and the panel for **QTabWidget** .

    An instance of the QStyleOptionTab class has **type**  **SO_Tab**  and
    **version**  3\\. The type is used internally by **QStyleOption** , its
    subclasses, and **qstyleoption_cast** () to determine the type of style
    option. In general you do not need to worry about this unless you want to
    create your own **QStyleOption**  subclass and your own styles. The version
    is used by **QStyleOption**  subclasses to implement extensions without
    breaking compatibility. If you use **qstyleoption_cast** (), you normally do
    not need to check it.

    For performance reasons, there are few member functions and the access to
    the member variables is direct (i.e., using the `.` or `->` operator). This
    makes the structures straightforward to use and emphasizes that these are
    simply parameters used by the style functions.

    For an example demonstrating how style options can be used, see the
    **Styles**  example.

    **See also** **QStyleOption** .
    """

    class TabFeature(enum.Flag):
        None_: QStyleOptionTab = ...
        HasFrame: QStyleOptionTab = ...

    class CornerWidget(enum.Flag):
        NoCornerWidgets: QStyleOptionTab = ...
        LeftCornerWidget: QStyleOptionTab = ...
        RightCornerWidget: QStyleOptionTab = ...

    class SelectedPosition(enum.Enum):
        NotAdjacent: QStyleOptionTab = ...
        NextIsSelected: QStyleOptionTab = ...
        PreviousIsSelected: QStyleOptionTab = ...

    class TabPosition(enum.Enum):
        Beginning: QStyleOptionTab = ...
        Middle: QStyleOptionTab = ...
        End: QStyleOptionTab = ...
        OnlyOneTab: QStyleOptionTab = ...

    class StyleOptionVersion(enum.Enum):
        Version: QStyleOptionTab = ...

    class StyleOptionType(enum.Enum):
        Type: QStyleOptionTab = ...

    cornerWidgets = ...
    documentMode: bool = ...
    features = ...
    icon: QtGui = ...
    iconSize: QtCore = ...
    leftButtonSize: QtCore = ...
    position = ...
    rightButtonSize: QtCore = ...
    row: int = ...
    selectedPosition = ...
    shape = ...
    tabIndex: int = ...
    text: str = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qstyleoptiontab.html#QStyleOptionTab

        **QStyleOptionTab::QStyleOptionTab()**

        Constructs a QStyleOptionTab object, initializing the members variables
        to their default values.
        """
        ...

    @typing.overload
    def __init__(self, other: "QStyleOptionTab") -> None:
        """
        https://doc.qt.io/qt-6/qstyleoptiontab.html#QStyleOptionTab-1

        **QStyleOptionTab::QStyleOptionTab(const QStyleOptionTab & other )**

        Constructs a copy of the **other** style option.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QVariant(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qvariant.html

    **Detailed Description**

    Because C++ forbids unions from including types that have non-default
    constructors or destructors, most interesting Qt classes cannot be used in
    unions. Without QVariant, this would be a problem for **QObject::property**
    () and for database work, etc.

    A QVariant object holds a single value of a single **typeId** () at a time.
    (Some types are multi-valued, for example a string list.) You can find out
    what type, T, the variant holds, convert it to a different type using
    **convert** (), get its value using one of the toT() functions (e.g.,
    **toSize** ()), and check whether the type can be converted to a particular
    type using **canConvert** ().

    The methods named toT() (e.g., **toInt** (), **toString** ()) are const. If
    you ask for the stored type, they return a copy of the stored object. If you
    ask for a type that can be generated from the stored type, toT() copies and
    converts and leaves the object itself unchanged. If you ask for a type that
    cannot be generated from the stored type, the result depends on the type;
    see the function documentation for details.

    Here is some example code to demonstrate the use of QVariant:

    **QDataStream**  out(...);
        **QVariant**  v(123);                // The
    variant now contains an int
        int x = v.toInt();              // x = 123
    out << v;                       // Writes a type tag and an int to out
        v
    = **QVariant** (tr("hello"));      // The variant now contains a QString
    int y = v.toInt();              // y = 0 since v cannot be converted to an
    int
        **QString**  s = v.toString();       // s = tr("hello")  (see
    QObject::tr())
        out << v;                       // Writes a type tag and
    a QString to out
        ...
        **QDataStream**  in(...);            //
    (opening the previously written stream)
        in >> v;
    // Reads an Int variant
        int z = v.toInt();              // z = 123
    **qDebug** ("Type is %s",            // prints "Type is int"
    v.typeName());
        v = v.toInt() + 100;            // The variant now holds
    the value 223
        v = **QVariant** (**QStringList** ());    // The variant
    now holds a QStringList

    You can even store **QList** <QVariant> and **QMap** <**QString** ,
    QVariant> values in a variant, so you can easily construct arbitrarily
    complex data structures of arbitrary types. This is very powerful and
    versatile, but may prove less memory and speed efficient than storing
    specific types in standard data structures.

    QVariant also supports the notion of null values. A variant is null if the
    variant contains no initialized value, or contains a null pointer.

    **QVariant**  x;                                // x.isNull() == true
    **QVariant**  y = **QVariant** ::fromValue(nullptr); // y.isNull() == true

    QVariant can be extended to support other types than those mentioned in the
    **QMetaType::Type**  enum. See **Creating Custom Qt Types**  for details.

    **A Note on GUI Types**

    Because QVariant is part of the Qt Core module, it cannot provide conversion
    functions to data types defined in Qt GUI, such as **QColor** , **QImage** ,
    and **QPixmap** . In other words, there is no `toColor()` function. Instead,
    you can use the **QVariant::value** () or the **qvariant_cast** () template
    function. For example:

    **QVariant**  variant;
        ...
        **QColor**  color =
    variant.value<**QColor** >();

    The inverse conversion (e.g., from **QColor**  to QVariant) is automatic for
    all data types supported by QVariant, including GUI-related types:

    **QColor**  color = palette().background().color();
        **QVariant**
    variant = color;

    **Using canConvert() and convert() Consecutively**

    When using **canConvert** () and **convert** () consecutively, it is
    possible for **canConvert** () to return true, but **convert** () to return
    false. This is typically because **canConvert** () only reports the general
    ability of QVariant to convert between types given suitable data; it is
    still possible to supply data which cannot actually be converted.

    For example, `canConvert(QMetaType::fromType<int>())` would return true when
    called on a variant containing a string because, in principle, QVariant is
    able to convert strings of numbers to integers. However, if the string
    contains non-numeric characters, it cannot be converted to an integer, and
    any attempt to convert it will fail. Hence, it is important to have both
    functions return true for a successful conversion.

    **See also** **QMetaType** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qvariant.html#QVariant

        **QVariant::QVariant()**

        Constructs an invalid variant.
        """
        ...

    @typing.overload
    def __init__(self, obj: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qvariant.html#QVariant-1

        **QVariant::QVariant(QMetaType type , const void * copy = nullptr)**

        Constructs variant of type **type** , and initializes with **copy** if
        **copy** is not `nullptr`.

        Note that you have to pass the address of the variable you want stored.

        Usually, you never have to use this constructor, use
        **QVariant::fromValue** () instead to construct variants from the
        pointer types represented by `QMetaType::VoidStar`, and
        `QMetaType::QObjectStar`.

        **See also** **QVariant::fromValue** () and **QMetaType::Type** .
        """
        ...

    @typing.overload
    def __init__(self, a0: "QVariant") -> None:
        """
        https://doc.qt.io/qt-6/qvariant.html#QVariant-2

        **QVariant::QVariant(const QVariant & p )**

        Constructs a copy of the variant, **p** , passed as the argument to this
        constructor.
        """
        ...

    def typeId(self) -> int:
        ...

    def canView(self, targetType: QMetaType) -> bool:
        """
        https://doc.qt.io/qt-6/qvariant.html#canView-1

        **template <typename T> bool QVariant::canView() const**

        Returns `true` if a mutable view of the template type `T` can be created
        on this variant, otherwise `false`.

        **See also** **value** ().
        """
        ...

    def metaType(self) -> QMetaType:
        """
        https://doc.qt.io/qt-6/qvariant.html#metaType

        **[since 6.0] QMetaType QVariant::metaType() const**

        Returns the **QMetaType**  of the value stored in the variant.

        This function was introduced in Qt 6.0.
        """
        ...

    def swap(self, other: "QVariant") -> None:
        """
        https://doc.qt.io/qt-6/qvariant.html#swap

        **void QVariant::swap(QVariant & other )**

        Swaps variant **other** with this variant. This operation is very fast
        and never fails.
        """
        ...

    def save(self, ds: QDataStream) -> None:
        ...

    def load(self, ds: QDataStream) -> None:
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qvariant.html#clear

        **void QVariant::clear()**

        Convert this variant to type **QMetaType::UnknownType**  and free up any
        resources used.
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qvariant.html#isNull

        **bool QVariant::isNull() const**

        Returns `true` if this is a null variant, false otherwise.

        A variant is considered null if it contains no initialized value or a
        null pointer.

        **Note:** This behavior has been changed from Qt 5, where isNull() would
        also return true if the variant contained an object of a builtin type
        with an isNull() method that returned true for that object.

        **See also** **convert** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qvariant.html#isValid

        **bool QVariant::isValid() const**

        Returns `true` if the storage type of this variant is not
        **QMetaType::UnknownType** ; otherwise returns `false`.
        """
        ...

    def convert(self, type: QMetaType) -> bool:
        """
        https://doc.qt.io/qt-6/qvariant.html#convert

        **[since 6.0] bool QVariant::convert(QMetaType targetType )**

        Casts the variant to the requested type, **targetType**. If the cast
        cannot be done, the variant is still changed to the requested type, but
        is left in a cleared null state similar to that constructed by
        **QVariant** (Type).

        Returns `true` if the current type of the variant was successfully cast;
        otherwise returns `false`.

        A **QVariant**  containing a pointer to a type derived from **QObject**
        will also convert and return true for this function if a
        **qobject_cast**  to the type described by **targetType** would succeed.
        Note that this only works for **QObject**  subclasses which use the
        **Q_OBJECT**  macro.

        **Note:** converting QVariants that are null due to not being
        initialized or having failed a previous conversion will always fail,
        changing the type, remaining null, and returning `false`.

        This function was introduced in Qt 6.0.

        **See also** **canConvert** () and **clear** ().
        """
        ...

    def canConvert(self, targetType: QMetaType) -> bool:
        """
        https://doc.qt.io/qt-6/qvariant.html#canConvert

        **[since 6.0] bool QVariant::canConvert(QMetaType type ) const**

        Returns `true` if the variant's type can be cast to the requested type,
        **type**. Such casting is done automatically when calling the **toInt**
        (), **toBool** (), ... methods.

        This function was introduced in Qt 6.0.

        **See also** **QMetaType::canConvert** ().
        """
        ...

    def typeName(self) -> str:
        """
        https://doc.qt.io/qt-6/qvariant.html#typeName

        **const char *QVariant::typeName() const**

        Returns the name of the type stored in the variant. The returned strings
        describe the C++ datatype used to store the data: for example,
        "**QFont** ", "**QString** ", or "QVariantList". An Invalid variant
        returns 0.
        """
        ...

    def userType(self) -> int:
        ...

    def value(self) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qvariant.html#value

        **template <typename T> T QVariant::value() const**

        Returns the stored value converted to the template type `T`. Call
        **canConvert** () to find out whether a type can be converted. If the
        value cannot be converted, a **default-constructed value**  will be
        returned.

        If the type `T` is supported by **QVariant** , this function behaves
        exactly as **toString** (), **toInt** () etc.

        Example:

        **QVariant**  v;

            MyCustomStruct c;
            if
        (v.canConvert<MyCustomStruct>())
                c = v.value<MyCustomStruct>();
        v = 7;
            int i = v.value<int>();                        // same as
        v.toInt()
            **QString**  s = v.value<**QString** >();
        // same as v.toString(), s is now "7"
            MyCustomStruct c2 =
        v.value<MyCustomStruct>(); // conversion failed, c2 is empty

        If the **QVariant**  contains a pointer to a type derived from
        **QObject**  then `T` may be any **QObject**  type. If the pointer
        stored in the **QVariant**  can be **qobject_cast**  to T, then that
        result is returned. Otherwise `nullptr` is returned. Note that this only
        works for **QObject**  subclasses which use the **Q_OBJECT**  macro.

        If the **QVariant**  contains a sequential container and `T` is
        QVariantList, the elements of the container will be converted into
        **QVariant** s and returned as a QVariantList.

        **QList** <int> intList = {7, 11, 42};

            **QVariant**  variant =
        **QVariant** ::fromValue(intList);
            if
        (variant.canConvert<QVariantList>()) {
                **QSequentialIterable**
        iterable = variant.value<**QSequentialIterable** >();
                // Can use
        foreach:
                foreach (const **QVariant**  &v, iterable) {
        **qDebug** () << v;
                }
                // Can use C++11 range-for:
        for (const **QVariant**  &v : iterable) {
                    **qDebug** () <<
        v;
                }
                // Can use iterators:
        **QSequentialIterable** ::const_iterator it = iterable.begin();
        const **QSequentialIterable** ::const_iterator end = iterable.end();
        for ( ; it != end; ++it) {
                    **qDebug** () << *it;
                }
        }

        **See also** **setValue** (), **fromValue** (), **canConvert** (), and
        **Q_DECLARE_SEQUENTIAL_CONTAINER_METATYPE** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QTreeView(QAbstractItemView):
    """
    https://doc.qt.io/qt-6/qtreeview.html

    **Detailed Description**

    ![](images/windows-treeview.png)

    A QTreeView implements a tree representation of items from a model. This
    class is used to provide standard hierarchical lists that were previously
    provided by the `QListView` class, but using the more flexible approach
    provided by Qt's model/view architecture.

    The QTreeView class is one of the **Model/View Classes**  and is part of
    Qt's **model/view framework** .

    QTreeView implements the interfaces defined by the **QAbstractItemView**
    class to allow it to display data provided by models derived from the
    **QAbstractItemModel**  class.

    It is simple to construct a tree view displaying data from a model. In the
    following example, the contents of a directory are supplied by a
    **QFileSystemModel**  and displayed as a tree:

    **QFileSystemModel**  *model = new **QFileSystemModel** ;
    model->setRootPath(**QDir** ::currentPath());
            **QTreeView**  *tree =
    new **QTreeView** (splitter);
            tree->setModel(model);

    The model/view architecture ensures that the contents of the tree view are
    updated as the model changes.

    Items that have children can be in an expanded (children are visible) or
    collapsed (children are hidden) state. When this state changes a
    **collapsed** () or **expanded** () signal is emitted with the model index
    of the relevant item.

    The amount of indentation used to indicate levels of hierarchy is controlled
    by the **indentation**  property.

    Headers in tree views are constructed using the **QHeaderView**  class and
    can be hidden using `header()->hide()`. Note that each header is configured
    with its **stretchLastSection**  property set to true, ensuring that the
    view does not waste any of the space assigned to it for its header. If this
    value is set to true, this property will override the resize mode set on the
    last section in the header.

    By default, all columns in a tree view are movable except the first. To
    disable movement of these columns, use **QHeaderView** 's
    **setSectionsMovable** () function. For more information about rearranging
    sections, see **Moving Header Sections** .

    **Key Bindings**

    QTreeView supports a set of key bindings that enable the user to navigate in
    the view and interact with the contents of items:

    KeyAction
    UpMoves the cursor to the item in the same column on the
    previous row. If the parent of the current item has no more rows to navigate
    to, the cursor moves to the relevant item in the last row of the sibling
    that precedes the parent.
    DownMoves the cursor to the item in the same
    column on the next row. If the parent of the current item has no more rows
    to navigate to, the cursor moves to the relevant item in the first row of
    the sibling that follows the parent.
    LeftHides the children of the current
    item (if present) by collapsing a branch.
    MinusSame as Left.
    RightReveals the children of the current item (if present) by expanding a
    branch.
    PlusSame as Right.
    AsteriskExpands the current item and all its
    children (if present).
    PageUpMoves the cursor up one page.
    PageDownMoves
    the cursor down one page.
    HomeMoves the cursor to an item in the same
    column of the first row of the first top-level item in the model.
    EndMoves
    the cursor to an item in the same column of the last row of the last top-
    level item in the model.
    F2In editable models, this opens the current item
    for editing. The Escape key can be used to cancel the editing process and
    revert any changes to the data displayed.

    **Improving Performance**

    It is possible to give the view hints about the data it is handling in order
    to improve its performance when displaying large numbers of items. One
    approach that can be taken for views that are intended to display items with
    equal heights is to set the **uniformRowHeights**  property to true.

    **See also** **QListView** , **QTreeWidget** , **View Classes** ,
    **QAbstractItemModel** , **QAbstractItemView** , and **Dir View Example** .
    """

    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#QTreeView

        **QTreeView::QTreeView(QWidget * parent = nullptr)**

        Constructs a tree view with a **parent** to represent a model's data.
        Use **setModel** () to set the model.

        **See also** **QAbstractItemModel** .
        """
        ...

    def expandRecursively(self, index: QtCore.QModelIndex, depth: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#expandRecursively

        **[slot, since 5.13] void QTreeView::expandRecursively(const QModelIndex
        & index , int depth = -1)**

        Expands the item at the given **index** and all its children to the
        given **depth**. The **depth** is relative to the given **index**. A
        **depth** of -1 will expand all children, a **depth** of 0 will only
        expand the given **index**.

        **Note:** This function will not try to **fetch more**  data.

        **Warning:** If the model contains a large number of items, this
        function will take some time to execute.

        This function was introduced in Qt 5.13.

        **See also** **expandAll** ().
        """
        ...

    def resetIndentation(self) -> None:
        ...

    def viewportSizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qtreeview.html#viewportSizeHint

        **[override virtual protected] QSize QTreeView::viewportSizeHint()
        const**

        Reimplements: **QAbstractItemView::viewportSizeHint() const** .
        """
        ...

    def treePosition(self) -> int:
        """
        https://doc.qt.io/qt-6/qtreeview.html#treePosition

        **[since 5.2] int QTreeView::treePosition() const**

        Return the logical index the tree is set on. If the return value is -1
        then the tree is placed on the visual index 0.

        This function was introduced in Qt 5.2.

        **See also** **setTreePosition** ().
        """
        ...

    def setTreePosition(self, logicalIndex: int) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#setTreePosition

        **[since 5.2] void QTreeView::setTreePosition(int index )**

        This specifies that the tree structure should be placed at logical index
        **index**. If  set to -1 then the tree will always follow visual index
        0.

        This function was introduced in Qt 5.2.

        **See also** **treePosition** (), **QHeaderView::swapSections** (), and
        **QHeaderView::moveSection** ().
        """
        ...

    def setHeaderHidden(self, hide: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#headerHidden-prop

        **headerHidden : bool**

        This property holds whether the header is shown or not.

        If this property is `true`, the header is not shown otherwise it is. The
        default value is false.

        **Access functions:**

        bool **isHeaderHidden** () const
        void **setHeaderHidden** (bool
        **hide** )

        **See also** **header** ().
        """
        ...

    def isHeaderHidden(self) -> bool:
        ...

    def setExpandsOnDoubleClick(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#expandsOnDoubleClick-prop

        **expandsOnDoubleClick : bool**

        This property holds whether the items can be expanded by double-
        clicking.

        This property holds whether the user can expand and collapse items by
        double-clicking. The default value is true.

        **Access functions:**

        bool **expandsOnDoubleClick** () const
        void
        **setExpandsOnDoubleClick** (bool **enable** )

        **See also** **itemsExpandable** .
        """
        ...

    def expandsOnDoubleClick(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtreeview.html#expandsOnDoubleClick-prop

        **expandsOnDoubleClick : bool**

        This property holds whether the items can be expanded by double-
        clicking.

        This property holds whether the user can expand and collapse items by
        double-clicking. The default value is true.

        **Access functions:**

        bool **expandsOnDoubleClick** () const
        void
        **setExpandsOnDoubleClick** (bool **enable** )

        **See also** **itemsExpandable** .
        """
        ...

    def currentChanged(
        self, current: QtCore.QModelIndex, previous: QtCore.QModelIndex
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#currentChanged

        **[override virtual protected] void QTreeView::currentChanged(const
        QModelIndex & current , const QModelIndex & previous )**

        Reimplements: **QAbstractItemView::currentChanged** (const QModelIndex
        &current, const QModelIndex &previous).
        """
        ...

    def selectionChanged(
        self, selected: QtCore.QItemSelection, deselected: QtCore.QItemSelection
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#selectionChanged

        **[override virtual protected] void QTreeView::selectionChanged(const
        QItemSelection & selected , const QItemSelection & deselected )**

        Reimplements: **QAbstractItemView::selectionChanged** (const
        QItemSelection &selected, const QItemSelection &deselected).
        """
        ...

    def rowHeight(self, index: QtCore.QModelIndex) -> int:
        """
        https://doc.qt.io/qt-6/qtreeview.html#rowHeight

        **[protected] int QTreeView::rowHeight(const QModelIndex & index )
        const**

        Returns the height of the row indicated by the given **index**.

        **See also** **indexRowSizeHint** ().
        """
        ...

    def viewportEvent(self, event: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qtreeview.html#viewportEvent

        **[override virtual protected] bool QTreeView::viewportEvent(QEvent *
        event )**

        Reimplements: **QAbstractItemView::viewportEvent** (QEvent *event).
        """
        ...

    def dragMoveEvent(self, event: QtGui.QDragMoveEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#dragMoveEvent

        **[override virtual protected] void
        QTreeView::dragMoveEvent(QDragMoveEvent * event )**

        Reimplements: **QAbstractItemView::dragMoveEvent** (QDragMoveEvent
        *event).
        """
        ...

    def expandToDepth(self, depth: int) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#expandToDepth

        **[slot] void QTreeView::expandToDepth(int depth )**

        Expands all expandable items to the given **depth**.

        **Note:** This function will not try to **fetch more**  data.

        **See also** **expandAll** (), **collapseAll** (), **expand** (),
        **collapse** (), and **setExpanded** ().
        """
        ...

    def wordWrap(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtreeview.html#wordWrap-prop

        **wordWrap : bool**

        This property holds the item text word-wrapping policy

        If this property is `true` then the item text is wrapped where necessary
        at word-breaks; otherwise it is not wrapped at all. This property is
        `false` by default.

        Note that even if wrapping is enabled, the cell will not be expanded to
        fit all text. Ellipsis will be inserted according to the current
        **textElideMode** .

        **Access functions:**

        bool **wordWrap** () const
        void **setWordWrap** (bool **on** )

        **Member Function Documentation**
        """
        ...

    def setWordWrap(self, on: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#wordWrap-prop

        **wordWrap : bool**

        This property holds the item text word-wrapping policy

        If this property is `true` then the item text is wrapped where necessary
        at word-breaks; otherwise it is not wrapped at all. This property is
        `false` by default.

        Note that even if wrapping is enabled, the cell will not be expanded to
        fit all text. Ellipsis will be inserted according to the current
        **textElideMode** .

        **Access functions:**

        bool **wordWrap** () const
        void **setWordWrap** (bool **on** )

        **Member Function Documentation**
        """
        ...

    def setFirstColumnSpanned(
        self, row: int, parent: QtCore.QModelIndex, span: bool
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#setFirstColumnSpanned

        **void QTreeView::setFirstColumnSpanned(int row , const QModelIndex &
        parent , bool span )**

        If **span** is true the item in the first column in the **row** with the
        given **parent** is set to span all columns, otherwise all items on the
        **row** are shown.

        **See also** **isFirstColumnSpanned** ().
        """
        ...

    def isFirstColumnSpanned(self, row: int, parent: QtCore.QModelIndex) -> bool:
        """
        https://doc.qt.io/qt-6/qtreeview.html#isFirstColumnSpanned

        **bool QTreeView::isFirstColumnSpanned(int row , const QModelIndex &
        parent ) const**

        Returns `true` if the item in first column in the given **row** of the
        **parent** is spanning all the columns; otherwise returns `false`.

        **See also** **setFirstColumnSpanned** ().
        """
        ...

    def setAutoExpandDelay(self, delay: int) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#autoExpandDelay-prop

        **autoExpandDelay : int**

        This property holds the delay time before items in a tree are opened
        during a drag and drop operation.

        This property holds the amount of time in milliseconds that the user
        must wait over a node before that node will automatically open or close.
        If the time is set to less then 0 then it will not be activated.

        By default, this property has a value of -1, meaning that auto-expansion
        is disabled.

        **Access functions:**

        int **autoExpandDelay** () const
        void **setAutoExpandDelay** (int
        **delay** )
        """
        ...

    def autoExpandDelay(self) -> int:
        """
        https://doc.qt.io/qt-6/qtreeview.html#autoExpandDelay-prop

        **autoExpandDelay : int**

        This property holds the delay time before items in a tree are opened
        during a drag and drop operation.

        This property holds the amount of time in milliseconds that the user
        must wait over a node before that node will automatically open or close.
        If the time is set to less then 0 then it will not be activated.

        By default, this property has a value of -1, meaning that auto-expansion
        is disabled.

        **Access functions:**

        int **autoExpandDelay** () const
        void **setAutoExpandDelay** (int
        **delay** )
        """
        ...

    def sortByColumn(self, column: int, order: QtCore.Qt.SortOrder) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#sortByColumn

        **[slot] void QTreeView::sortByColumn(int column , Qt::SortOrder order
        )**

        Sorts the model by the values in the given **column** and **order**.

        **column** may be -1, in which case no sort indicator will be shown and
        the model will return to its natural, unsorted order. Note that not all
        models support this and may even crash in this case.

        **See also** **sortingEnabled** .
        """
        ...

    def allColumnsShowFocus(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtreeview.html#allColumnsShowFocus-prop

        **allColumnsShowFocus : bool**

        This property holds whether items should show keyboard focus using all
        columns

        If this property is `true` all columns will show focus, otherwise only
        one column will show focus.

        The default is false.

        **Access functions:**

        bool **allColumnsShowFocus** () const
        void **setAllColumnsShowFocus**
        (bool **enable** )
        """
        ...

    def setAllColumnsShowFocus(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#allColumnsShowFocus-prop

        **allColumnsShowFocus : bool**

        This property holds whether items should show keyboard focus using all
        columns

        If this property is `true` all columns will show focus, otherwise only
        one column will show focus.

        The default is false.

        **Access functions:**

        bool **allColumnsShowFocus** () const
        void **setAllColumnsShowFocus**
        (bool **enable** )
        """
        ...

    def isAnimated(self) -> bool:
        ...

    def setAnimated(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#animated-prop

        **animated : bool**

        This property holds whether animations are enabled

        If this property is `true` the treeview will animate expansion and
        collapsing of branches. If this property is `false`, the treeview will
        expand or collapse branches immediately without showing the animation.

        By default, this property is `false`.

        **Access functions:**

        bool **isAnimated** () const
        void **setAnimated** (bool **enable** )
        """
        ...

    def isSortingEnabled(self) -> bool:
        ...

    def setSortingEnabled(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#sortingEnabled-prop

        **sortingEnabled : bool**

        This property holds whether sorting is enabled

        If this property is `true`, sorting is enabled for the tree; if the
        property is false, sorting is not enabled. The default value is false.

        **Note:** In order to avoid performance issues, it is recommended that
        sorting is enabled **after** inserting the items into the tree.
        Alternatively, you could also insert the items into a list before
        inserting the items into the tree.

        **Access functions:**

        bool **isSortingEnabled** () const
        void **setSortingEnabled** (bool
        **enable** )

        **See also** **sortByColumn** ().
        """
        ...

    def setColumnWidth(self, column: int, width: int) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#setColumnWidth

        **void QTreeView::setColumnWidth(int column , int width )**

        Sets the width of the given **column** to the **width** specified.

        **See also** **columnWidth** () and **resizeColumnToContents** ().
        """
        ...

    def isIndexHidden(self, index: QtCore.QModelIndex) -> bool:
        """
        https://doc.qt.io/qt-6/qtreeview.html#isIndexHidden

        **[override virtual protected] bool QTreeView::isIndexHidden(const
        QModelIndex & index ) const**

        Reimplements: **QAbstractItemView::isIndexHidden(const QModelIndex
        &index) const** .
        """
        ...

    def horizontalScrollbarAction(self, action: int) -> None:
        ...

    def indexRowSizeHint(self, index: QtCore.QModelIndex) -> int:
        """
        https://doc.qt.io/qt-6/qtreeview.html#indexRowSizeHint

        **[protected] int QTreeView::indexRowSizeHint(const QModelIndex & index
        ) const**

        Returns the size hint for the row indicated by **index**.

        **See also** **sizeHintForColumn** () and **uniformRowHeights** ().
        """
        ...

    def sizeHintForColumn(self, column: int) -> int:
        """
        https://doc.qt.io/qt-6/qtreeview.html#sizeHintForColumn

        **[override virtual protected] int QTreeView::sizeHintForColumn(int
        column ) const**

        Reimplements: **QAbstractItemView::sizeHintForColumn(int column) const**
        .

        Returns the size hint for the **column** 's width or -1 if there is no
        model.

        If you need to set the width of a given column to a fixed value, call
        **QHeaderView::resizeSection** () on the view's header.

        If you reimplement this function in a subclass, note that the value you
        return is only used when **resizeColumnToContents** () is called. In
        that case, if a larger column width is required by either the view's
        header or the item delegate, that width will be used instead.

        **See also** **QWidget::sizeHint** , **header** (), and
        **QHeaderView::resizeContentsPrecision** ().
        """
        ...

    def updateGeometries(self) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#updateGeometries

        **[override virtual protected] void QTreeView::updateGeometries()**

        Reimplements: **QAbstractItemView::updateGeometries** ().
        """
        ...

    def keyPressEvent(self, event: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#keyPressEvent

        **[override virtual protected] void QTreeView::keyPressEvent(QKeyEvent *
        event )**

        Reimplements: **QAbstractItemView::keyPressEvent** (QKeyEvent *event).
        """
        ...

    def mouseDoubleClickEvent(self, e: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#mouseDoubleClickEvent

        **[override virtual protected] void
        QTreeView::mouseDoubleClickEvent(QMouseEvent * event )**

        Reimplements: **QAbstractItemView::mouseDoubleClickEvent** (QMouseEvent
        *event).
        """
        ...

    def mouseMoveEvent(self, event: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#mouseMoveEvent

        **[override virtual protected] void
        QTreeView::mouseMoveEvent(QMouseEvent * event )**

        Reimplements: **QAbstractItemView::mouseMoveEvent** (QMouseEvent
        *event).
        """
        ...

    def mousePressEvent(self, e: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#mousePressEvent

        **[override virtual protected] void
        QTreeView::mousePressEvent(QMouseEvent * event )**

        Reimplements: **QAbstractItemView::mousePressEvent** (QMouseEvent
        *event).
        """
        ...

    def drawTree(self, painter: QtGui.QPainter, region: QtGui.QRegion) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#drawTree

        **[protected] void QTreeView::drawTree(QPainter * painter , const
        QRegion & region ) const**

        Draws the part of the tree intersecting the given **region** using the
        specified **painter**.

        **See also** **paintEvent** ().
        """
        ...

    def drawBranches(
        self, painter: QtGui.QPainter, rect: QtCore.QRect, index: QtCore.QModelIndex
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#drawBranches

        **[virtual protected] void QTreeView::drawBranches(QPainter * painter ,
        const QRect & rect , const QModelIndex & index ) const**

        Draws the branches in the tree view on the same row as the model item
        **index** , using the **painter** given. The branches are drawn in the
        rectangle specified by **rect**.
        """
        ...

    def drawRow(
        self,
        painter: QtGui.QPainter,
        options: QStyleOptionViewItem,
        index: QtCore.QModelIndex,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#drawRow

        **[virtual protected] void QTreeView::drawRow(QPainter * painter , const
        QStyleOptionViewItem & option , const QModelIndex & index ) const**

        Draws the row in the tree view that contains the model item **index** ,
        using the **painter** given. The **option** controls how the item is
        displayed.

        **See also** **setAlternatingRowColors** ().
        """
        ...

    def mouseReleaseEvent(self, event: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#mouseReleaseEvent

        **[override virtual protected] void
        QTreeView::mouseReleaseEvent(QMouseEvent * event )**

        Reimplements: **QAbstractItemView::mouseReleaseEvent** (QMouseEvent
        *event).
        """
        ...

    def timerEvent(self, event: QtCore.QTimerEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#timerEvent

        **[override virtual protected] void QTreeView::timerEvent(QTimerEvent *
        event )**

        Reimplements: **QAbstractItemView::timerEvent** (QTimerEvent *event).
        """
        ...

    def paintEvent(self, e: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#paintEvent

        **[override virtual protected] void QTreeView::paintEvent(QPaintEvent *
        event )**

        Reimplements: **QAbstractScrollArea::paintEvent** (QPaintEvent *event).
        """
        ...

    def changeEvent(self, event: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#changeEvent

        **[override virtual protected] void QTreeView::changeEvent(QEvent *
        event )**

        Reimplements: **QFrame::changeEvent** (QEvent *ev).
        """
        ...

    def selectedIndexes(self) -> typing.List[QtCore.QModelIndex]:
        """
        https://doc.qt.io/qt-6/qtreeview.html#selectedIndexes

        **[override virtual protected] QModelIndexList
        QTreeView::selectedIndexes() const**

        Reimplements: **QAbstractItemView::selectedIndexes() const** .
        """
        ...

    def visualRegionForSelection(
        self, selection: QtCore.QItemSelection
    ) -> QtGui.QRegion:
        """
        https://doc.qt.io/qt-6/qtreeview.html#visualRegionForSelection

        **[override virtual protected] QRegion
        QTreeView::visualRegionForSelection(const QItemSelection & selection )
        const**

        Reimplements: **QAbstractItemView::visualRegionForSelection(const
        QItemSelection &selection) const** .

        Returns the rectangle from the viewport of the items in the given
        **selection**.

        Since 4.7, the returned region only contains rectangles intersecting (or
        included in) the viewport.
        """
        ...

    def setSelection(
        self, rect: QtCore.QRect, command: QtCore.QItemSelectionModel.SelectionFlag
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#setSelection

        **[override virtual protected] void QTreeView::setSelection(const QRect
        & rect , QItemSelectionModel::SelectionFlags command )**

        Reimplements: **QAbstractItemView::setSelection** (const QRect &rect,
        QItemSelectionModel::SelectionFlags flags).

        Applies the selection **command** to the items in or touched by the
        rectangle, **rect**.

        **See also** **selectionCommand** ().
        """
        ...

    def verticalOffset(self) -> int:
        """
        https://doc.qt.io/qt-6/qtreeview.html#verticalOffset

        **[override virtual protected] int QTreeView::verticalOffset() const**

        Reimplements: **QAbstractItemView::verticalOffset() const** .

        Returns the vertical offset of the items in the tree view.

        **See also** **horizontalOffset** ().
        """
        ...

    def horizontalOffset(self) -> int:
        """
        https://doc.qt.io/qt-6/qtreeview.html#horizontalOffset

        **[override virtual protected] int QTreeView::horizontalOffset() const**

        Reimplements: **QAbstractItemView::horizontalOffset() const** .

        Returns the horizontal offset of the items in the treeview.

        Note that the tree view uses the horizontal header section positions to
        determine the positions of columns in the view.

        **See also** **verticalOffset** ().
        """
        ...

    def moveCursor(
        self,
        cursorAction: QAbstractItemView.CursorAction,
        modifiers: QtCore.Qt.KeyboardModifier,
    ) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qtreeview.html#moveCursor

        **[override virtual protected] QModelIndex
        QTreeView::moveCursor(QAbstractItemView::CursorAction cursorAction ,
        Qt::KeyboardModifiers modifiers )**

        Reimplements: **QAbstractItemView::moveCursor**
        (QAbstractItemView::CursorAction cursorAction, Qt::KeyboardModifiers
        modifiers).

        Move the cursor in the way described by **cursorAction** , using the
        information provided by the button **modifiers**.
        """
        ...

    def rowsAboutToBeRemoved(
        self, parent: QtCore.QModelIndex, start: int, end: int
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#rowsAboutToBeRemoved

        **[override virtual protected] void
        QTreeView::rowsAboutToBeRemoved(const QModelIndex & parent , int start ,
        int end )**

        Reimplements: **QAbstractItemView::rowsAboutToBeRemoved** (const
        QModelIndex &parent, int start, int end).

        Informs the view that the rows from the **start** row to the **end** row
        inclusive are about to removed from the given **parent** model item.
        """
        ...

    def rowsInserted(self, parent: QtCore.QModelIndex, start: int, end: int) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#rowsInserted

        **[override virtual protected] void QTreeView::rowsInserted(const
        QModelIndex & parent , int start , int end )**

        Reimplements: **QAbstractItemView::rowsInserted** (const QModelIndex
        &parent, int start, int end).

        Informs the view that the rows from the **start** row to the **end** row
        inclusive have been inserted into the **parent** model item.
        """
        ...

    def scrollContentsBy(self, dx: int, dy: int) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#scrollContentsBy

        **[override virtual protected] void QTreeView::scrollContentsBy(int dx ,
        int dy )**

        Reimplements: **QAbstractScrollArea::scrollContentsBy** (int dx, int
        dy).

        Scrolls the contents of the tree view by ( **dx** , **dy** ).
        """
        ...

    def rowsRemoved(self, parent: QtCore.QModelIndex, first: int, last: int) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#rowsRemoved

        **[protected slot] void QTreeView::rowsRemoved(const QModelIndex &
        parent , int start , int end )**

        Informs the view that the rows from the **start** row to the **end** row
        inclusive have been removed from the given **parent** model item.
        """
        ...

    def reexpand(self) -> None:
        ...

    def columnMoved(self) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#columnMoved

        **[protected slot] void QTreeView::columnMoved()**

        This slot is called whenever a column has been moved.
        """
        ...

    def columnCountChanged(self, oldCount: int, newCount: int) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#columnCountChanged

        **[protected slot] void QTreeView::columnCountChanged(int oldCount , int
        newCount )**

        Informs the tree view that the number of columns in the tree view has
        changed from **oldCount** to **newCount**.
        """
        ...

    def columnResized(self, column: int, oldSize: int, newSize: int) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#columnResized

        **[protected slot] void QTreeView::columnResized(int column , int
        oldSize , int newSize )**

        This function is called whenever **column** 's size is changed in the
        header. **oldSize** and **newSize** give the previous size and the new
        size in pixels.

        **See also** **setColumnWidth** ().
        """
        ...

    def selectAll(self) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#selectAll

        **[override virtual] void QTreeView::selectAll()**

        Reimplements: **QAbstractItemView::selectAll** ().
        """
        ...

    def resizeColumnToContents(self, column: int) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#resizeColumnToContents

        **[slot] void QTreeView::resizeColumnToContents(int column )**

        Resizes the **column** given to the size of its contents.

        **See also** **columnWidth** (), **setColumnWidth** (),
        **sizeHintForColumn** (), and **QHeaderView::resizeContentsPrecision**
        ().
        """
        ...

    def collapseAll(self) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#collapseAll

        **[slot] void QTreeView::collapseAll()**

        Collapses all expanded items.

        **See also** **expandAll** (), **expand** (), **collapse** (), and
        **setExpanded** ().
        """
        ...

    def collapse(self, index: QtCore.QModelIndex) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#collapse

        **[slot] void QTreeView::collapse(const QModelIndex & index )**

        Collapses the model item specified by the **index**.

        **See also** **collapsed** ().
        """
        ...

    def expandAll(self) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#expandAll

        **[slot] void QTreeView::expandAll()**

        Expands all expandable items.

        **Note:** This function will not try to **fetch more**  data.

        **Warning:** If the model contains a large number of items, this
        function will take some time to execute.

        **See also** **collapseAll** (), **expand** (), **collapse** (), and
        **setExpanded** ().
        """
        ...

    def expand(self, index: QtCore.QModelIndex) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#expand

        **[slot] void QTreeView::expand(const QModelIndex & index )**

        Expands the model item specified by the **index**.

        **See also** **expanded** ().
        """
        ...

    def showColumn(self, column: int) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#showColumn

        **[slot] void QTreeView::showColumn(int column )**

        Shows the given **column** in the tree view.

        **See also** **hideColumn** () and **setColumnHidden** ().
        """
        ...

    def hideColumn(self, column: int) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#hideColumn

        **[slot] void QTreeView::hideColumn(int column )**

        Hides the **column** given.

        **Note:** This function should only be called after the model has been
        initialized, as the view needs to know the number of columns in order to
        hide **column**.

        **See also** **showColumn** () and **setColumnHidden** ().
        """
        ...

    def dataChanged(
        self,
        topLeft: QtCore.QModelIndex,
        bottomRight: QtCore.QModelIndex,
        roles: typing.Iterable[int] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#dataChanged

        **[override virtual] void QTreeView::dataChanged(const QModelIndex &
        topLeft , const QModelIndex & bottomRight , const QList<int> & roles =
        QList<int>())**

        Reimplements: **QAbstractItemView::dataChanged** (const QModelIndex
        &topLeft, const QModelIndex &bottomRight, const QList<int> &roles).
        """
        ...

    def reset(self) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#reset

        **[override virtual] void QTreeView::reset()**

        Reimplements: **QAbstractItemView::reset** ().
        """
        ...

    def indexBelow(self, index: QtCore.QModelIndex) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qtreeview.html#indexBelow

        **QModelIndex QTreeView::indexBelow(const QModelIndex & index ) const**

        Returns the model index of the item below **index**.
        """
        ...

    def indexAbove(self, index: QtCore.QModelIndex) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qtreeview.html#indexAbove

        **QModelIndex QTreeView::indexAbove(const QModelIndex & index ) const**

        Returns the model index of the item above **index**.
        """
        ...

    def indexAt(self, p: QtCore.QPoint) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qtreeview.html#indexAt

        **[override virtual] QModelIndex QTreeView::indexAt(const QPoint & point
        ) const**

        Reimplements: **QAbstractItemView::indexAt(const QPoint &point) const**
        .
        """
        ...

    def scrollTo(
        self, index: QtCore.QModelIndex, hint: QAbstractItemView.ScrollHint = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#scrollTo

        **[override virtual] void QTreeView::scrollTo(const QModelIndex & index
        , QAbstractItemView::ScrollHint hint = EnsureVisible)**

        Reimplements: **QAbstractItemView::scrollTo** (const QModelIndex &index,
        QAbstractItemView::ScrollHint hint).

        Scroll the contents of the tree view until the given model item
        **index** is visible. The **hint** parameter specifies more precisely
        where the item should be located after the operation. If any of the
        parents of the model item are collapsed, they will be expanded to ensure
        that the model item is visible.
        """
        ...

    def visualRect(self, index: QtCore.QModelIndex) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qtreeview.html#visualRect

        **[override virtual] QRect QTreeView::visualRect(const QModelIndex &
        index ) const**

        Reimplements: **QAbstractItemView::visualRect(const QModelIndex &index)
        const** .

        Returns the rectangle on the viewport occupied by the item at **index**.
        If the index is not visible or explicitly hidden, the returned rectangle
        is invalid.
        """
        ...

    def keyboardSearch(self, search: str) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#keyboardSearch

        **[override virtual] void QTreeView::keyboardSearch(const QString &
        search )**

        Reimplements: **QAbstractItemView::keyboardSearch** (const QString
        &search).
        """
        ...

    def setExpanded(self, index: QtCore.QModelIndex, expand: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#setExpanded

        **void QTreeView::setExpanded(const QModelIndex & index , bool expanded
        )**

        Sets the item referred to by **index** to either collapse or expanded,
        depending on the value of **expanded**.

        **See also** **expanded** (), **expand** (), and **isExpanded** ().
        """
        ...

    def isExpanded(self, index: QtCore.QModelIndex) -> bool:
        """
        https://doc.qt.io/qt-6/qtreeview.html#isExpanded

        **bool QTreeView::isExpanded(const QModelIndex & index ) const**

        Returns `true` if the model item **index** is expanded; otherwise
        returns false.

        **See also** **expand** (), **expanded** (), and **setExpanded** ().
        """
        ...

    def setRowHidden(self, row: int, parent: QtCore.QModelIndex, hide: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#setRowHidden

        **void QTreeView::setRowHidden(int row , const QModelIndex & parent ,
        bool hide )**

        If **hide** is true the **row** with the given **parent** is hidden,
        otherwise the **row** is shown.

        **See also** **isRowHidden** () and **setColumnHidden** ().
        """
        ...

    def isRowHidden(self, row: int, parent: QtCore.QModelIndex) -> bool:
        """
        https://doc.qt.io/qt-6/qtreeview.html#isRowHidden

        **bool QTreeView::isRowHidden(int row , const QModelIndex & parent )
        const**

        Returns `true` if the item in the given **row** of the **parent** is
        hidden; otherwise returns `false`.

        **See also** **setRowHidden** () and **isColumnHidden** ().
        """
        ...

    def setColumnHidden(self, column: int, hide: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#setColumnHidden

        **void QTreeView::setColumnHidden(int column , bool hide )**

        If **hide** is true the **column** is hidden, otherwise the **column**
        is shown.

        **See also** **isColumnHidden** (), **hideColumn** (), and
        **setRowHidden** ().
        """
        ...

    def isColumnHidden(self, column: int) -> bool:
        """
        https://doc.qt.io/qt-6/qtreeview.html#isColumnHidden

        **bool QTreeView::isColumnHidden(int column ) const**

        Returns `true` if the **column** is hidden; otherwise returns `false`.

        **See also** **hideColumn** () and **isRowHidden** ().
        """
        ...

    def columnAt(self, x: int) -> int:
        """
        https://doc.qt.io/qt-6/qtreeview.html#columnAt

        **int QTreeView::columnAt(int x ) const**

        Returns the column in the tree view whose header covers the **x**
        coordinate given.
        """
        ...

    def columnWidth(self, column: int) -> int:
        """
        https://doc.qt.io/qt-6/qtreeview.html#columnWidth

        **int QTreeView::columnWidth(int column ) const**

        Returns the width of the **column**.

        **See also** **resizeColumnToContents** () and **setColumnWidth** ().
        """
        ...

    def columnViewportPosition(self, column: int) -> int:
        """
        https://doc.qt.io/qt-6/qtreeview.html#columnViewportPosition

        **int QTreeView::columnViewportPosition(int column ) const**

        Returns the horizontal position of the **column** in the viewport.
        """
        ...

    def setItemsExpandable(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#itemsExpandable-prop

        **itemsExpandable : bool**

        This property holds whether the items are expandable by the user.

        This property holds whether the user can expand and collapse items
        interactively.

        By default, this property is `true`.

        **Access functions:**

        bool **itemsExpandable** () const
        void **setItemsExpandable** (bool
        **enable** )
        """
        ...

    def itemsExpandable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtreeview.html#itemsExpandable-prop

        **itemsExpandable : bool**

        This property holds whether the items are expandable by the user.

        This property holds whether the user can expand and collapse items
        interactively.

        By default, this property is `true`.

        **Access functions:**

        bool **itemsExpandable** () const
        void **setItemsExpandable** (bool
        **enable** )
        """
        ...

    def setUniformRowHeights(self, uniform: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#uniformRowHeights-prop

        **uniformRowHeights : bool**

        This property holds whether all items in the treeview have the same
        height

        This property should only be set to true if it is guaranteed that all
        items in the view has the same height. This enables the view to do some
        optimizations.

        The height is obtained from the first item in the view. It is updated
        when the data changes on that item.

        **Note:** If the editor size hint is bigger than the cell size hint,
        then the size hint of the editor will be used.

        By default, this property is `false`.

        **Access functions:**

        bool **uniformRowHeights** () const
        void **setUniformRowHeights**
        (bool **uniform** )
        """
        ...

    def uniformRowHeights(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtreeview.html#uniformRowHeights-prop

        **uniformRowHeights : bool**

        This property holds whether all items in the treeview have the same
        height

        This property should only be set to true if it is guaranteed that all
        items in the view has the same height. This enables the view to do some
        optimizations.

        The height is obtained from the first item in the view. It is updated
        when the data changes on that item.

        **Note:** If the editor size hint is bigger than the cell size hint,
        then the size hint of the editor will be used.

        By default, this property is `false`.

        **Access functions:**

        bool **uniformRowHeights** () const
        void **setUniformRowHeights**
        (bool **uniform** )
        """
        ...

    def setRootIsDecorated(self, show: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#rootIsDecorated-prop

        **rootIsDecorated : bool**

        This property holds whether to show controls for expanding and
        collapsing top-level items

        Items with children are typically shown with controls to expand and
        collapse them, allowing their children to be shown or hidden. If this
        property is false, these controls are not shown for top-level items.
        This can be used to make a single level tree structure appear like a
        simple list of items.

        By default, this property is `true`.

        **Access functions:**

        bool **rootIsDecorated** () const
        void **setRootIsDecorated** (bool
        **show** )
        """
        ...

    def rootIsDecorated(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtreeview.html#rootIsDecorated-prop

        **rootIsDecorated : bool**

        This property holds whether to show controls for expanding and
        collapsing top-level items

        Items with children are typically shown with controls to expand and
        collapse them, allowing their children to be shown or hidden. If this
        property is false, these controls are not shown for top-level items.
        This can be used to make a single level tree structure appear like a
        simple list of items.

        By default, this property is `true`.

        **Access functions:**

        bool **rootIsDecorated** () const
        void **setRootIsDecorated** (bool
        **show** )
        """
        ...

    def setIndentation(self, i: int) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#indentation-prop

        **indentation : int**

        indentation of the items in the tree view.

        This property holds the indentation measured in pixels of the items for
        each level in the tree view. For top-level items, the indentation
        specifies the horizontal distance from the viewport edge to the items in
        the first column; for child items, it specifies their indentation from
        their parent items.

        By default, the value of this property is style dependent. Thus, when
        the style changes, this property updates from it. Calling
        setIndentation() stops the updates, calling resetIndentation() will
        restore default behavior.

        **Access functions:**

        int **indentation** () const
        void **setIndentation** (int **i** )
        void **resetIndentation** ()
        """
        ...

    def indentation(self) -> int:
        """
        https://doc.qt.io/qt-6/qtreeview.html#indentation-prop

        **indentation : int**

        indentation of the items in the tree view.

        This property holds the indentation measured in pixels of the items for
        each level in the tree view. For top-level items, the indentation
        specifies the horizontal distance from the viewport edge to the items in
        the first column; for child items, it specifies their indentation from
        their parent items.

        By default, the value of this property is style dependent. Thus, when
        the style changes, this property updates from it. Calling
        setIndentation() stops the updates, calling resetIndentation() will
        restore default behavior.

        **Access functions:**

        int **indentation** () const
        void **setIndentation** (int **i** )
        void **resetIndentation** ()
        """
        ...

    def setHeader(self, header: QHeaderView) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#setHeader

        **void QTreeView::setHeader(QHeaderView * header )**

        Sets the header for the tree view, to the given **header**.

        The view takes ownership over the given **header** and deletes it when a
        new header is set.

        **See also** **QAbstractItemModel::headerData** ().
        """
        ...

    def header(self) -> QHeaderView:
        """
        https://doc.qt.io/qt-6/qtreeview.html#header

        **QHeaderView *QTreeView::header() const**

        Returns the header for the tree view.

        **See also** **setHeader** () and **QAbstractItemModel::headerData** ().
        """
        ...

    def setSelectionModel(self, selectionModel: QtCore.QItemSelectionModel) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#setSelectionModel

        **[override virtual] void
        QTreeView::setSelectionModel(QItemSelectionModel * selectionModel )**

        Reimplements: **QAbstractItemView::setSelectionModel**
        (QItemSelectionModel *selectionModel).
        """
        ...

    def setRootIndex(self, index: QtCore.QModelIndex) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#setRootIndex

        **[override virtual] void QTreeView::setRootIndex(const QModelIndex &
        index )**

        Reimplements: **QAbstractItemView::setRootIndex** (const QModelIndex
        &index).
        """
        ...

    def setModel(self, model: QtCore.QAbstractItemModel) -> None:
        """
        https://doc.qt.io/qt-6/qtreeview.html#setModel

        **[override virtual] void QTreeView::setModel(QAbstractItemModel * model
        )**

        Reimplements: **QAbstractItemView::setModel** (QAbstractItemModel
        *model).
        """
        ...

    @property
    def collapsed(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtreeview.html#collapsed

        **[signal] void QTreeView::collapsed(const QModelIndex & index )**

        This signal is emitted when the item specified by **index** is
        collapsed.
        """
        ...

    @property
    def expanded(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtreeview.html#expanded

        **[signal] void QTreeView::expanded(const QModelIndex & index )**

        This signal is emitted when the item specified by **index** is expanded.

        **See also** **setExpanded** ().
        """
        ...
